@@ -5,13 +5,14 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/contacts/register_contacts', [
     'io.ox/core/extensions',
     'oxguard/pgp/publickeys',
+    'settings!oxguard',
     'less!oxguard/style'
-], function (ext, pubkeys) {
+], function (ext, pubkeys, settings) {
 
     ext.point('io.ox/contacts/detail').extend({
         id: 'pgppublic',
@@ -19,10 +20,14 @@ define('oxguard/contacts/register_contacts', [
         draw: function (baton) {
             //FIXME: this completely disables the point for apps other than settings and contacts (like mail called from sidepanel)
             if (!(baton.app && baton.app.cid)) return;
-
-            var list = (baton.data.email1 ? baton.data.email1 : '') + ',' + (baton.data.email2 ? baton.data.email2 : '') + ',' + (baton.data.email3 ? baton.data.email3 : '');
+            if (!settings.get('advanced')) return;  //advanced view only
+            var list = (baton.data.email1 ? baton.data.email1 : '') + (baton.data.email2 ? (',' + baton.data.email2) : '') + (baton.data.email3 ? (',' + baton.data.email3) : '');
             var newfield = $('<fieldset class="block" data-block="pgp">');
-            $(this).find('.clearfix').append(newfield.append(pubkeys.listPublic(baton.app.cid, list)));
+            var location = $(this).find('article.clearfix');
+            if (location[0] !== undefined) {
+                $(location[0]).append(newfield.append(pubkeys.listPublic(baton.app.cid, list)));
+            }
+
         }
     });
 });
