@@ -5,7 +5,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/files/register', [
     'io.ox/core/extensions',
@@ -25,7 +25,7 @@ define('oxguard/files/register', [
     // For mobile, add a decrypt button
     ext.point('io.ox/files/details').extend({
         index: 500,
-        id: 'downloadOGsmall',
+        id: 'downloadGuardsmall',
         draw: function (baton) {
             if (_.device('small')) {
                 if (_.device('ios')) return;   // ios doesn't allow downloading.
@@ -34,20 +34,11 @@ define('oxguard/files/register', [
                     download.click(function (ev) {
                         ev.preventDefault();
                         var list = [baton.data];
-                        if (extrapasslist(list)) {
-                            oxPasswordPrompt('download', list, true);
-                            return;
-                        }
-                        if (window.oxguarddata === undefined) {
-                            oxPasswordPrompt('download', list, false);
-                            return;
-                        }
-                        if ((window.oxguarddata.passcode === null) || (window.oxguarddata.passcode.length < 20)) {
-                            oxPasswordPrompt('download', list, false);
-                            return;
-                        }
-                        require (['oxguard/files/downloader'], function (downloader) {
-                            downloader.getFile(list, 'download', window.oxguarddata.passcode);
+                        authenticate().then(function (data) {
+                            require (['oxguard/files/downloader'], function (downloader) {
+                                metrics('guard', 'decrypt & download');
+                                downloader.getFile(list, 'download', data.auth);
+                            });
                         });
                     });
                     $(this).append(download);
@@ -105,7 +96,7 @@ define('oxguard/files/register', [
         index: 1200,
         prio: 'lo',
         mobile: 'lo',
-        label: gt('Send copy by mail'),
+        label: gt('Send by mail'),
         ref: 'oxguard/sendcopy',
         section: 'share'
     }));
@@ -127,7 +118,7 @@ define('oxguard/files/register', [
     });
 
     ext.point('io.ox/core/viewer/toolbar/links/drive').extend(new links.Link({
-        id: 'OGViewerEncrypt',
+        id: 'GuardViewerEncrypt',
         index: 200,
         label: gt('Encrypt'),
         ref: 'oxguard/encrypt',
@@ -135,7 +126,7 @@ define('oxguard/files/register', [
     }));
 
     ext.point('io.ox/core/viewer/toolbar/links/guard').extend(new links.Link({
-        id: 'OGViewerEncrypt',
+        id: 'GuardViewerRemEncrypt',
         index: 200,
         label: gt('Remove Encryption'),
         ref: 'oxguard/remencrypt',
@@ -143,7 +134,7 @@ define('oxguard/files/register', [
     }));
 
     ext.point('io.ox/core/viewer/toolbar/links/guard').extend(new links.Link({
-        id: 'OGViewerDownload',
+        id: 'GuardViewerDownload',
         index: 200,
         label: gt('Download Decrypted'),
         ref: 'oxguard/download',
@@ -151,7 +142,7 @@ define('oxguard/files/register', [
     }));
 
     ext.point('io.ox/core/viewer/toolbar/links/guard').extend(new links.Link({
-        id: 'OGViewerSend',
+        id: 'GuardViewerSend',
         index: 201,
         label: gt('Send copy by mail'),
         ref: 'oxguard/sendcopy',
@@ -176,21 +167,21 @@ define('oxguard/files/register', [
 
     // Versions
     ext.point('io.ox/files/versions/links/inline').extend(new links.Link({
-        id: 'OGView',
+        id: 'GuardView',
         index: 90,
         label: gt('View'),
         ref: 'oxguard/versionView'
     }));
 
     ext.point('io.ox/files/versions/links/inline').extend(new links.Link({
-        id: 'OGopen',
+        id: 'GuardOpen',
         index: 100,
         label: gt('Decrypt and Open'),
         ref: 'oxguard/open'
     }));
 
     ext.point('io.ox/files/versions/links/inline').extend(new links.Link({
-        id: 'OGdownload',
+        id: 'GuardDownload',
         index: 200,
         label: gt('Download Decrypted'),
         ref: 'oxguard/download'
@@ -199,7 +190,7 @@ define('oxguard/files/register', [
     // Remove the loc portion of the name in version list
     ext.point('io.ox/files/details/version').extend({
         index: 1,
-        id: 'ogversion',
+        id: 'GuardVersion',
         draw: function () {}
     });
 
@@ -237,6 +228,7 @@ define('oxguard/files/register', [
                             });
                             fileUpload.setWindowNode(app.getWindowNode());
                             fileUpload.setAPI(api);
+                            metrics('guard', 'upload & encrypt');
                             var ul = fileUpload.create;
                             ul.on('stop', function () {
                                 fileUpload.setAPI(origAPI);
@@ -303,7 +295,7 @@ define('oxguard/files/register', [
             if (util.isMailvelope ()) return false;
             //all files must be encrypted
             var toCheck = e.baton.models === null ? e.baton.model : e.baton.models;
-            return e.collection.has('some') && util.encryptedOnly(toCheck) && util.isNotAttachment(toCheck) && capabilities.has('webmail');
+            return e.collection.has('some') && util.hasEncrypted(toCheck) && util.isNotAttachment(toCheck) && capabilities.has('webmail');
         },
         multiple: function (list) {
             list.map(function (file) {
@@ -323,9 +315,10 @@ define('oxguard/files/register', [
             var opt = {
                 extraPassword: extrapasslist (list)
             };
-            var win = baton.app.getWindow();
+            var win = baton.app === undefined ? null : baton.app.getWindow();
             authenticate(opt).then(function (auth) {
-                win.busy();
+                if (win !== null) win.busy();
+                metrics('guard', 'remove-encryption');
                 api.removeEncryption((baton.models === null ? baton.model : baton.models), auth)
                 .then(function () {
                     if (baton.context !== undefined && baton.context.viewerEvents !== undefined) {
@@ -334,7 +327,7 @@ define('oxguard/files/register', [
                     reload();
                 })
                 .always(function () {
-                    win.idle();
+                    if (win !== null) win.idle();
                 });
             });
             baton.openedBy = 'io.ox/files';
@@ -353,21 +346,12 @@ define('oxguard/files/register', [
             return (false);
         },
         multiple: function (list) {
-            if (extrapasslist(list)) {
-                oxPasswordPrompt('open', list, true);
-                return;
-            }
-            if (window.oxguarddata === undefined) {
-                oxPasswordPrompt('open', list, false);
-                return;
-            }
-            if ((window.oxguarddata.passcode === null) || (window.oxguarddata.passcode.length < 20)) {
-                oxPasswordPrompt('open', list, false);
-                return;
-            }
-            var popup = window.open('', '_blank');
-            require (['oxguard/files/downloader'], function (downloader) {
-                downloader.getFile(list, 'open', window.oxguarddata.passcode, null, popup);
+            authenticate().then(function (data) {
+                var popup = window.open('', '_blank');
+                require (['oxguard/files/downloader'], function (downloader) {
+                    metrics('guard', 'decrypt & open');
+                    downloader.getFile(list, 'open', data.auth, null, popup);
+                });
             });
         }
     });
@@ -380,44 +364,25 @@ define('oxguard/files/register', [
             return e.collection.has('some') && util.encryptedOnly(toCheck) && util.isNotAttachment(toCheck);
         },
         multiple: function (list) {
-            if (extrapasslist(list)) {
-                oxPasswordPrompt('download', list, true);
-                return;
-            }
-            if (window.oxguarddata === undefined) {
-                oxPasswordPrompt('download', list, false);
-                return;
-            }
-            if ((window.oxguarddata.passcode === null) || (window.oxguarddata.passcode.length < 20)) {
-                oxPasswordPrompt('download', list, false);
-                return;
-            }
-            require (['oxguard/files/downloader'], function (downloader) {
-                downloader.getFile(list, 'download', window.oxguarddata.passcode);
+            authenticate().then(function (data) {
+                require (['oxguard/files/downloader'], function (downloader) {
+                    metrics('guard', 'decrypt & download');
+                    downloader.getFile(list, 'download', data.auth);
+                });
             });
         }
     });
 
     ////// Main listview handling
-    // For each item, if Guard file, intercept double click or enter to bring up Guard pasword prompt
-    ext.point('io.ox/files/listview/item').extend ({
-        id: 'GuardEvents',
-        index: 200000,
-        draw: function (baton) {
-            if (isOGFile (baton.data)) {
-                var ev = _.device('touch') ? 'tap' : 'dblclick';
-                $(this).unbind(ev);
-                $(this).parent().unbind(ev);
-                $(this).on(ev, function (e) {
-                    e.stopImmediatePropagation();
-                    viewFile (baton.data);
-                }).parent().keydown(function (e) {
-                    if (e.keyCode === 13) {
-                        e.stopImmediatePropagation();
-                        viewFile (baton.data);
-                        return false;
-                    }
-                });
+
+    ext.point('io.ox/files/actions/default').extend({
+        id: 'first',
+        action: function (baton) {
+            console.log(baton);
+            if (baton.data.meta && baton.data.meta.Encrypted === true) {
+                baton.stopPropagation();
+                metrics('guard', 'view-encrypted');
+                viewFile (baton.data);
             }
         }
     });
@@ -444,16 +409,10 @@ define('oxguard/files/register', [
     function viewFile (file) {
         if (isOGFile (file)) {
             var list = [file];
-            if (window.oxguarddata === undefined) {
-                oxPasswordPrompt('view', list, extrapasslist(list));
-                return;
-            }
-            if ((window.oxguarddata.passcode === null) || (window.oxguarddata.passcode.length < 20)) {
-                oxPasswordPrompt('view', list, extrapasslist(list));
-                return;
-            }
-            require (['oxguard/files/downloader'], function (downloader) {
-                downloader.getFile(list, 'view', window.oxguarddata.passcode);
+            authenticate().then(function (data) {
+                require (['oxguard/files/downloader'], function (downloader) {
+                    downloader.getFile(list, 'view', data.auth);
+                });
             });
         }
     }
@@ -462,19 +421,31 @@ define('oxguard/files/register', [
     // Add drop zone for Guard.  For now, hide button
     ext.point('io.ox/core/viewer/views/sidebarview/detail').extend({
         id: 'guardDetailFile',
-        draw: function () {
+        index: 10000,
+        draw: function (baton) {
             if (util.isMailvelope ()) return false;
-            if (this.model.isEncrypted()) {
-                var input = this.$el.find('.viewer-uploadnewversion').find('input[type="file"]');
-                var file = this.model;
-                input.unbind().on('change', function (e) {
-                    e.stopImmediatePropagation();
-                    // do upload here
-                    uploadNewVersion(this, file);
-                });
-                if (this.zone !== null) {
-                    this.zone.unbind('drop');
-                    this.zone.bind('drop', uploadNewGuardVersion.bind(this));
+            if (baton.model.isEncrypted()) {
+                if (baton.context.zone !== null) {
+                    baton.context.zone.unbind('drop');
+                    baton.context.zone.bind('drop', uploadNewGuardVersion.bind(baton.context));
+                }
+            }
+        }
+    });
+
+    ext.point('io.ox/core/viewer/views/sidebarview/uploadnewversion').extend({
+        id: 'guardUploadNewVersion',
+        index: 1,
+        draw: function () {
+            if (this.model !== null && this.model !== undefined) {
+                if (this.model.isEncrypted()) {
+                    var input = this.$el.find('input[type="file"]');
+                    var file = this.model;
+                    input.unbind().on('change', function (e) {
+                        e.stopImmediatePropagation();
+                        // do upload here
+                        uploadNewVersion(this, file);
+                    });
                 }
             }
         }
@@ -517,18 +488,21 @@ define('oxguard/files/register', [
 
             zone2.on({
                 'drop': function (files) {
-                    require(['io.ox/files/upload/main', 'io.ox/files/api'], function (fileUpload, origAPI) {
-                        var list = [];
-                        _(files).each(function (file) {
-                            list.push(_.extend(file, { group: 'file' }));
+                    ensureSetup().then(function () {
+                        metrics('guard', 'dropfile upload & encrypt');
+                        require(['io.ox/files/upload/main', 'io.ox/files/api'], function (fileUpload, origAPI) {
+                            var list = [];
+                            _(files).each(function (file) {
+                                list.push(_.extend(file, { group: 'file' }));
+                            });
+                            fileUpload.setWindowNode(app.getWindowNode());
+                            fileUpload.setAPI(api);
+                            var ul = fileUpload.create;
+                            ul.on('stop', function () {
+                                fileUpload.setAPI(origAPI);
+                            });
+                            ul.offer(list, { folder: app.folder.get() });
                         });
-                        fileUpload.setWindowNode(app.getWindowNode());
-                        fileUpload.setAPI(api);
-                        var ul = fileUpload.create;
-                        ul.on('stop', function () {
-                            fileUpload.setAPI(origAPI);
-                        });
-                        ul.offer(list, { folder: app.folder.get() });
                     });
                 }
             });
@@ -550,90 +524,52 @@ define('oxguard/files/register', [
     ////// Functions / util
 
     function authenticate (opt) {
+        var def = $.Deferred();
         opt = opt || {};
         if (!opt.extraPassword && window.oxguarddata && window.oxguarddata.passcode && window.oxguarddata.passcode.length >= 20) {
-            return $.when({
-                auth: window.oxguarddata.passcode
-            });
-        }
-        var def = $.Deferred();
-        require(['io.ox/core/tk/dialogs', 'io.ox/core/notifications'], function (dialogs, notifications) {
-            var dialog = new dialogs.CreateDialog({ width: 450, center: true,  enter: 'ok' });
-            dialog.header($('<h4>').text(gt('Enter Guard Security Password')));
-            var passdiv = $('<div>').addClass('row-fluid');
-            passdiv.append('<input name="ogpassword" type="password"/>');
-            var remember = false;
-            var rememberdiv = $('<div><span style="padding:5px;">' + gt('Remember Password') + '</span></div>');
-            var reminput = $('<input type="checkbox" name="rememberpass" style="margin:0 0 0;">')
-                .click(function () {
-                    remember = $('input[name="rememberpass"]').is(':checked');
-                });
-            var duration = $('<select id="fduration" class="og_duration"><option value="10">' + gt('10 minutes') + '</option>' +
-                    '<option value="20">' + gt('20 minutes') + '</option>' +
-                    '<option value="30">' + gt('30 minutes') + '</option>' +
-                    '<option value="60">' + gt('1 hour') + '</option>' +
-                    '<option value="120">' + gt('2 hours') + '</option>' +
-                    '<option value="99999">' + gt('Session') + '</option' +
-                    '</select>')
-                    .on('change', function () {
-                        $('input[name="rememberpass"]').prop('checked', true);
-                        remember = true;
-                    });
-            var extraprompt = $('<div style="padding-top:10px;"><span>' + gt('Extra Password') + ': </span><input type="password" id="extra"/></div>');
-            if (!opt.extraPassword) {
-                rememberdiv.prepend(reminput);
-                rememberdiv.append(duration);
-                passdiv.append(rememberdiv);
-            }
-            dialog.getBody().append(passdiv);
-            if (opt.extraPassword) dialog.getBody().append(extraprompt);
-            dialog
-            .addPrimaryButton('ok', gt('OK'), 'ok')
-            .addButton('cancel', gt('Cancel'), 'cancel')
-            .on('ok', function () {
-                var extrapass = $('#extra').val();
-                var time = $('#fduration').val() * 1000 * 60;
-                var popup = null;
-                oxguard.auth(ox.user_id, $('input[name="ogpassword"]').val(), extrapass)
-                .done(function (data) {
-                    if (data.auth === 'Bad Password') {
-                        if (popup) popup.close();
-                        //#. Bad, incorrect password
-                        notifications.yell('error', gt('Bad password'));
-                        return;
-                    }
-                    if (data.auth === 'Lockout') {
-                        if (popup) popup.close();
-                        notifications.yell('error', gt('Temporary Lockout'));
-                        return;
-                    }
-                    if (remember) {
-                        window.oxguarddata.passcode = data.auth;
-                        $('.og_signout').show();
-                        window.setTimeout(function () {
-                            window.oxguarddata.passcode = null;
-                            $('.og_signout').hide();
-                        }, time);
-                    }
-                    def.resolve(data);
+            oxguard.checkAuth()  // make sure valid session before going on
+            .done(function () {
+                def.resolve({
+                    auth: window.oxguarddata.passcode
                 });
+                return;
             })
-            .show(function () {
-                if (!_.device('ios')) {
-                    $('input[name="ogpassword"]').focus();
-                    window.setTimeout(function () {
-                        $('input[name="ogpassword"]').focus();
-                    }, 100);
-                }
+            .fail(function () {
+                window.oxguarddata.passcode = null;
+                def.reject();
             });
+            return def;
+        }
+        oxguard.getPassword(gt('Enter %s Security Password', window.oxguarddata.productName), true)  //Get password
+        .done(function (passdata) {
+            if (passdata.duration > -1) {
+                oxguard.savePassword(passdata.password, passdata.duration)
+                .done(function (data) {
+                    def.resolve(data);
+                })
+                .fail(function (data) {
+                    handleFail (data);
+                    def.reject(data);
+                });
+            } else {
+                oxguard.auth(ox.user_id, passdata.password)
+                .done(function (data) {
+                    if (data.auth.length > 20) {
+                        def.resolve(data);
+                    } else {
+                        handleFail(data);
+                        def.reject(data);
+                    }
+                });
+            }
         });
-
         return def;
     }
 
     function ensureSetup() {
 
         if (!util.isGuardConfigured()) {
+            oxguard.metrics('drive', 'create-keys');
             return oxguard.createKeysWizard(true);
         }
 
@@ -650,7 +586,7 @@ define('oxguard/files/register', [
             return e.collection.has('some') && !util.encryptedOnly(e.baton.models);
         },
         multiple: function (list, baton) {
-            var win = baton.app.getWindow();
+            var win = baton.app === undefined ? null : baton.app.getWindow();
             ensureSetup().then(function () {
                 // Check if there are multiple versions
                 var multipleVersions = baton.models.reduce(function (acc, file) {
@@ -688,7 +624,9 @@ define('oxguard/files/register', [
                     return def;
                 }
             }).then(function () {
-                win.busy();
+                metrics('guard', 'encrypt-file');
+                if (win !== null) win.busy();
+
                 return api.encrypt(baton.models)
                 .then(function () {
                     if (baton.context !== undefined && baton.context.viewerEvents !== undefined) {
@@ -707,7 +645,7 @@ define('oxguard/files/register', [
                     });
                 })
                 .always(function () {
-                    win.idle();
+                    if (win !== null) win.idle();
                 });
             });
         }
@@ -715,6 +653,18 @@ define('oxguard/files/register', [
 
     /////////////////  Util, prompts, etc
 
+    function metrics (target, action) {
+        require(['io.ox/metrics/main'], function (metrics) {
+            if (!metrics.isEnabled()) return;
+            metrics.trackEvent({
+                app: 'drive',
+                target: target,
+                type: 'click',
+                action: action
+            });
+        });
+    }
+
     function uploadNewVersion (input, orig) {
         var files = input.files;
         require(['io.ox/core/tk/dialogs'], function (Dialogs) {
@@ -745,88 +695,25 @@ define('oxguard/files/register', [
         });
     }
 
-    // Create a password prompt for the oxguard password
-    function oxPasswordPrompt(action, list, extra) {
-        require(['io.ox/core/tk/dialogs', 'io.ox/core/notifications', 'oxguard/files/downloader'], function (dialogs, notifications, downloader) {
-            var dialog = new dialogs.CreateDialog({ width: 450, center: true,  enter: 'ok' });
-            dialog.header($('<h4>').text(gt('Enter Guard Security Password')));
-            var passdiv = $('<div>').addClass('row-fluid');
-            passdiv.append('<input name="ogpassword" type="password" style="margin-bottom:10px;"/>');
-            var rem = false;
-            var rememberdiv = $('<div><span style="padding:5px;">' + gt('Remember Password') + '</span></div>');
-            var reminput = $('<input type="checkbox" name="rememberpass" style="margin:0 0 0;">')
-                .click(function () {
-                    rem = $('input[name="rememberpass"]').is(':checked');
-                });
-            var duration = $('<select id="fduration" class="og_duration"><option value="10">' + gt('10 minutes') + '</option>' +
-                    '<option value="20">' + gt('20 minutes') + '</option>' +
-                    '<option value="30">' + gt('30 minutes') + '</option>' +
-                    '<option value="60">' + gt('1 hour') + '</option>' +
-                    '<option value="120">' + gt('2 hours') + '</option>' +
-                    '<option value="99999">' + gt('Session') + '</option' +
-                    '</select>')
-                    .on('change', function () {
-                        $('input[name="rememberpass"]').prop('checked', true);
-                        rem = true;
-                    });
-            var extraprompt = $('<div style="padding-top:10px;"><span>' + gt('Extra Password') + ': </span><input type="password" id="extra"/></div>');
-            if (!extra) {
-                rememberdiv.prepend(reminput);
-                rememberdiv.append(duration);
-                passdiv.append(rememberdiv);
+    function handleFail (data, popup) {
+        require(['io.ox/core/notifications'], function (notifications) {
+            if (data.auth === 'Bad RSA') {
+                window.oxguarddata.pubkey = null;
+                return;
+            }
+            if (data.auth === 'Bad Password') {
+                if (popup) popup.close();
+                //#. Bad, incorrect password
+                notifications.yell('error', gt('Bad password'));
+                return;
+            }
+            if (data.auth === 'Lockout') {
+                if (popup) popup.close();
+                notifications.yell('error', gt('Temporary Lockout'));
+                return;
             }
-            dialog.getBody().append(passdiv);
-            if (extra) dialog.getBody().append(extraprompt);
-            dialog
-            .addPrimaryButton('ok', gt('OK'), 'ok')
-            .addButton('cancel', gt('Cancel'), 'cancel')
-            .on('ok', function () {
-                var extrapass = $('#extra').val();
-                var time = $('#fduration').val() * 1000 * 60;
-                var popup = null;
-                if (action === 'open') {
-                    popup = window.open('', '_blank');
-                }
-                var password = $('input[name="ogpassword"]').val();
-                oxguard.auth(ox.user_id, password, extrapass)
-                .done(function (data) {
-                    if (data.auth === 'Bad RSA') {
-                        window.oxguarddata.pubkey = null;
-                        return;
-                    }
-                    if (data.auth === 'Bad Password') {
-                        if (popup) popup.close();
-                        //#. Bad, incorrect password
-                        notifications.yell('error', gt('Bad password'));
-                        return;
-                    }
-                    if (data.auth === 'Lockout') {
-                        if (popup) popup.close();
-                        notifications.yell('error', gt('Temporary Lockout'));
-                        return;
-                    }
-                    if (rem) {
-                        window.oxguarddata.passcode = data.auth;
-                        $('.og_signout').show();
-                        window.setTimeout(function () {
-                            window.oxguarddata.passcode = null;
-                            $('.og_signout').hide();
-                        }, time);
-                    }
-                    downloader.getFile(list, action, data.auth, data.encrExtra, popup);
-
-                });
-            })
-            .show(function () {
-                if (!_.device('ios')) {
-                    $('input[name="ogpassword"]').focus();
-                    window.setTimeout(function () {
-                        $('input[name="ogpassword"]').focus();
-                    }, 100);
-                }
-
-            });
         });
+
     }
 
     function reload () {
