@@ -4,7 +4,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/files/share', [
     'io.ox/core/extensions',
@@ -229,7 +229,8 @@ define('oxguard/files/share', [
     function getPassword(data, node, fileid, addressBook) {
         var dialog = new dialogs.CreateDialog({ width: 490, center: true,  enter: 'ok' });
         dialog.header($('<h4>').text(gt('Password Needed')));
-        var help = $('<p>' + gt('Please provide your Guard Security Password to share this file') + '</p>');
+        //#. %s product name
+        var help = $('<p>' + gt('Please provide your %s Security Password to share this file', window.oxguarddata.productName) + '</p>');
         var pass = $('<input name="password" id="password" type="password"/>');
         dialog.getBody().append(help).append(pass);
         dialog.addPrimaryButton('ok', gt('OK'), 'ok')
