@@ -5,7 +5,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 
 define('oxguard/mail/keymanager', ['oxguard/core/og_http'],
@@ -46,14 +46,23 @@ define('oxguard/mail/keymanager', ['oxguard/core/og_http'],
         };
         baton.model.get('gkeys').push(result);
         var params = '&email=' + email + '&cid=' + ox.context_id + '&from=' +
-        encodeURIComponent(baton.model.get('from')[1]) + '&userid=' + ox.user_id +
-        '&session=' + ox.session;
-        og_http.get(ox.apiRoot + '/oxguard/mail?action=getkey', params)
+        encodeURIComponent(baton.model.get('from')[1]) + '&userid=' + ox.user_id;
+        og_http.get(ox.apiRoot + '/oxguard/pgpmail?action=getkey', params)
         .done(function (data) {//Get the key
             try {
+                if ($.isArray(data)) {  // error responses sent as array
+                    data = data[0];
+                }
                 if (data.inline) { // If needs inline, then set
                     if (baton.model.set('PGPFormat', 'inline'));
                 }
+                if (data.error) {
+                    updateKeys (email, baton, 'fail');
+                    require (['io.ox/core/notifications'], function (notifications) {
+                        if (data.error)
+                            notifications.yell('error', data.error);
+                    });
+                }
                 if (data.pgp === true) {
                     updateKeys (email, baton, 'pgp');
                     return;
@@ -80,6 +89,7 @@ define('oxguard/mail/keymanager', ['oxguard/core/og_http'],
             }
         });
         baton.model.set('gkeys', gkeys);
+        baton.model.trigger('change:gkeys');
         updateTokens(baton);
     }
 
