@@ -5,7 +5,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/mail/mail_extensions_compose', [
     'io.ox/core/extensions',
@@ -13,8 +13,9 @@ define('oxguard/mail/mail_extensions_compose', [
     'io.ox/mail/util',
     'settings!io.ox/mail',
     'io.ox/core/api/account',
+    'oxguard/mail/mail_metrics',
     'gettext!oxguard'
-], function (ext, prep, util, settings, account, gt) {
+], function (ext, prep, util, settings, account, metrics, gt) {
     'use strict';
 
     var isDraftFolder = function (folder_id) {
@@ -44,10 +45,18 @@ define('oxguard/mail/mail_extensions_compose', [
                 return;
             }
             try {
-                if (window.oxguarddata.current.og || window.oxguarddata.current.PGP) {
-                    doReply(false);
-                    baton.preventDefault();
-                    //baton.disable('io.ox/mail/actions/reply', 'default');
+                if (window.oxguarddata.current !== null) {
+                    if (window.oxguarddata.current.og || window.oxguarddata.current.PGP) {
+                        metrics.track('reply-pgp-email');
+                        doReply(false);
+                        baton.disable('io.ox/mail/actions/reply', 'default');
+                        return;
+                    }
+                }
+                if (baton.data.pgp_found) {
+                    require (['io.ox/core/notifications'], function (notify) {
+                        notify.yell('warning', gt('You are replying to an email that has not yet been decoded.  The recipient will not be able to read the contents of the original email.'));
+                    });
                 }
             } catch (e) {
                 console.log(e);
@@ -67,8 +76,8 @@ define('oxguard/mail/mail_extensions_compose', [
             if (!e.collection.has('one') && !e.baton.isThread) return;
             // get first mail
             var data = e.baton.first();
-            // other recipients that me? and not a draft mail
-            return util.hasOtherRecipients(data) && !isDraftMail(data);
+            // has recipients  and not a draft mail
+            return util.hasFrom(data) && !isDraftMail(data);
         },
         action: function (baton) {
             getCurrent(baton);
@@ -78,11 +87,16 @@ define('oxguard/mail/mail_extensions_compose', [
                 if (data.PGPDecoded) {  // If we have PGP decode data, then use it to compose new email
                     window.oxguarddata.action = 'secureReply';
                     doReply (data, true);
-                    baton.preventDefault();
-                    //baton.disable('io.ox/mail/actions/reply-all', 'reply-all');
+                    metrics.track('replyAll-pgp-email');
+                    baton.disable('io.ox/mail/actions/reply-all', 'default');
                     return;
                 }
             }
+            if (baton.data.pgp_found) {
+                require (['io.ox/core/notifications'], function (notify) {
+                    notify.yell('warning', gt('You are replying to an email that has not yet been decoded.  The recipient will not be able to read the contents of the original email.'));
+                });
+            }
         }
     });
 
@@ -95,13 +109,18 @@ define('oxguard/mail/mail_extensions_compose', [
         action: function (baton) {
             getCurrent(baton);
             if (window.oxguarddata.current && window.oxguarddata.current.PGPDecoded) {
-                var data = window.oxguarddata.current;
+                var data = JSON.parse(JSON.stringify(window.oxguarddata.current));
                 window.oxguarddata.action = 'secureReply';
                 doForward (data);
-                baton.preventDefault();
-                //baton.disable('io.ox/mail/actions/forward', 'forward');
+                metrics.track('forward-pgp-email');
+                baton.disable('io.ox/mail/actions/forward', 'default');
                 return;
             }
+            if (baton.data.pgp_found) {
+                require (['io.ox/core/notifications'], function (notify) {
+                    notify.yell('warning', gt('You are forwarding an email that has not yet been decoded.  The recipient will not be able to read the contents of the original email.'));
+                });
+            }
         }
     });
 
@@ -134,6 +153,7 @@ define('oxguard/mail/mail_extensions_compose', [
                 getCurrent(baton);
                 window.oxguarddata.action = 'fileAttach';
                 doDraft (window.oxguarddata.current);
+                metrics.track('edit-pgp-draft');
                 baton.preventDefault();
                 //baton.disable('io.ox/mail/actions/edit', 'edit');
                 return;
@@ -149,7 +169,16 @@ define('oxguard/mail/mail_extensions_compose', [
             window.oxguarddata.current = baton.data[0].Guard;
             return;
         }
-        window.oxguarddata.current = baton.data.Guard;
+        if (baton.view !== undefined) {
+            if (baton.view.model.get('Guard') !== undefined) {
+                window.oxguarddata.current = baton.view.model.get('Guard');
+                return;
+            }
+        }
+        if (baton.data.Guard !== undefined) {
+            window.oxguarddata.current = baton.data.Guard;
+        }
+
     }
 
     ext.point('io.ox/mail/actions/compose').replace({
@@ -196,20 +225,53 @@ define('oxguard/mail/mail_extensions_compose', [
             data.headers.References = data.headers.References + ' ' + data.headers['Message-ID'];
         }
         data.subject = gt ('Re: %1$s', data.subject);
-        openEditor (data);
+        openEditor (data, 0);
     }
 
-    function openEditor (data) {
+    // Open editor
+    // Type undefined or 0 = reply,  type 1 = forward, type 2 = draft
+    function openEditor (data, type) {
         if (getFormatType(data) === 'text') {
-            ox.registry.call('mail-compose', 'compose', { to: data.to, cc: data.cc, subject: data.subject, attachments: data.attachments, editorMode: 'text', preferredEditorMode: 'text', content_type: 'text' })
+            ox.registry.call('mail-compose', 'compose',
+                {
+                    to: data.to, cc: data.cc,
+                    subject: data.subject,
+                    msgref: data.msgref,
+                    attachments: data.attachments,
+                    editorMode: 'text', preferredEditorMode: 'text',
+                    content_type: 'text',
+                    'defaultSignatureId': (type === 2 ? 0 : settings.get('defaultReplyForwardSignature'))
+                })
             .done(function (e) {
-                e.app.view.editor.focus();
+                if (type && type === 1 ) {  // If forwarding, then put the focus in to, otherwise body
+                    e.app.view.$el.find('.tokenfield.to').focus();
+                } else {
+                    window.setTimeout(function () {
+                        e.app.view.editor.focus();
+                        e.app.view.editor.setCaretPosition();
+                    }, 200);
+                }
                 checkSaved(data, e.app.model);
             });
         } else {
-            ox.registry.call('mail-compose', 'compose', { to: data.to, cc: data.cc, subject: data.subject, attachments: data.attachments, editorMode: 'html' })
+            ox.registry.call('mail-compose', 'compose',
+                {
+                    to: data.to, cc: data.cc,
+                    subject: data.subject,
+                    msgref: data.msgref,
+                    attachments: data.attachments,
+                    editorMode: 'html',
+                    'defaultSignatureId': (type === 2 ? 0 : settings.get('defaultReplyForwardSignature'))
+                })
             .done(function (e) {
-                e.app.view.editor.focus();
+                if (type && type === 1) {  // If forwarding, then put the focus in to, otherwise body
+                    e.app.view.$el.find('.tokenfield.to').focus();
+                } else {
+                    window.setTimeout(function () {
+                        e.app.view.editor.focus();
+                        e.app.view.editor.setCaretPosition();
+                    }, 200);
+                }
                 checkSaved(data, e.app.model);
             });
         }
@@ -238,6 +300,10 @@ define('oxguard/mail/mail_extensions_compose', [
             if (headers['X-OxGuard-Format'] !== undefined) {
                 model.set('PGPFormat', headers['X-OxGuard-Format']);
             }
+            window.setTimeout(function () {
+                model.dirty(false);
+            }, 1000);
+
         } catch (e) {
             console.log(e);
         }
@@ -274,16 +340,20 @@ define('oxguard/mail/mail_extensions_compose', [
         var newto = [];
         //   var user = baton.app.getView().form.find('.sender-dropdown').val();// Get current users email
         var user = settings.get('defaultSendAddress', '');
-        for (var i = 0; i < to.length; i++) {
-            if (user.indexOf(to[i][1]) < 0) { // dont add the user to recip list
-                newto.push(to[i]);
+        if (to) {
+            for (var i = 0; i < to.length; i++) {
+                if (user.indexOf(to[i][1]) < 0) { // dont add the user to recip list
+                    newto.push(to[i]);
+                }
             }
         }
         var cc = window.oxguarddata.current.cc;
         var newcc = [];
-        for (var i = 0; i < cc.length; i++) {
-            if (user.indexOf(cc[i][1]) < 0) { // dont add the user to recip list
-                newcc.push(cc[i]);
+        if (cc) {
+            for (var i = 0; i < cc.length; i++) {
+                if (user.indexOf(cc[i][1]) < 0) { // dont add the user to recip list
+                    newcc.push(cc[i]);
+                }
             }
         }
         return {
@@ -334,7 +404,9 @@ define('oxguard/mail/mail_extensions_compose', [
             }
             data.attachments = attachments;
             data.subject = gt ('Fwd: %1$s', data.subject);
-            openEditor (data);
+            data.to = [];  // Remove all recipients as forwarding
+            data.cc = [];
+            openEditor (data, 1);
         });
     }
 
@@ -354,6 +426,7 @@ define('oxguard/mail/mail_extensions_compose', [
         }
         data.attachments = attachments;
         data.msgref = msgref;
-        openEditor (data);
+        openEditor (data, 2);
     }
+
 });
