@@ -17,7 +17,9 @@ define('oxguard/mail/maillist', [
     function listViewInit() {
         require (['io.ox/mail/main'], function (main) {
             var app = main.getApp();
-            app.listView.on('selection:change', change);
+            if (app.listView !== undefined) {
+                app.listView.on('selection:change', change);
+            }
         });
     }
 
@@ -33,25 +35,14 @@ define('oxguard/mail/maillist', [
         }
     });
 
-    // Extension point for List view, change in 7.6.1
-    if (ox.serverConfig.version.indexOf('7.6.0') === 0) {
-        ext.point('io.ox/mail/listview/item/small/col4').extend({
-            id: 'OGpaper-clipSm',
-            index: 300,
-            draw: function (baton) {
-                addLock.call(this, baton);
-            }
-        });
-    } else {
-        ext.point('io.ox/mail/listview/item/small/col5').disable('paper-clip');
-        ext.point('io.ox/mail/listview/item/small/col5').extend({
-            id: 'OGpaper-clipSm',
-            index: 300,
-            draw: function (baton) {
-                addLock.call(this, baton);
-            }
-        });
-    }
+    ext.point('io.ox/mail/listview/item/small/col5').disable('paper-clip');
+    ext.point('io.ox/mail/listview/item/small/col5').extend({
+        id: 'OGpaper-clipSm',
+        index: 300,
+        draw: function (baton) {
+            addLock.call(this, baton);
+        }
+    });
 
     // Check if OxGuard email, and if so, add lock icon.  Add paperclip if applicable
     function addLock(baton) {
@@ -73,6 +64,9 @@ define('oxguard/mail/maillist', [
                 return;
             }
             var attachments = baton.model.get('attachments');
+            if (attachments === undefined) {
+                return;
+            }
             /// PGP Components
             // Check if decoded
             if (baton.model.get('PGPDecoded') === true) {
