@@ -5,7 +5,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 
 define('oxguard/mail/options_new', [
@@ -28,9 +28,6 @@ define('oxguard/mail/options_new', [
     function setLock (baton) {
         if (baton.model.get('encrypt')) {
             core.lock(baton);
-            if (window.oxguarddata.settings.pgpsign) {
-                baton.model.set('PGPSignature', true);
-            }
         } else {
             core.unlock(baton);
         }
@@ -47,13 +44,24 @@ define('oxguard/mail/options_new', [
             var dialog = new dialogs.CreateDialog({ width: 450, height: 300, center: true });
             dialog.header($('<h4>').text(gt('HTML Formatted Email')));
             var body = $('<p>');
-            body.append(gt('HTML formatted emails may cause issues with PGP inline.  Click OK to change to Plain Text formatted Emails'));
+            body.append(gt('HTML formatted emails may cause issues with PGP inline.  Click OK to change to Plain Text formatted Emails.'));
             dialog.getBody().append(body);
             dialog
             .addPrimaryButton('ok', gt('OK'), 'okx')
             .addButton('cancel', gt('Cancel'), 'cancel')
             .on('ok', function () {
                 baton.model.set('editorMode', 'text');
+                baton.model.on('change:editorMode', function () {
+                    if ((baton.model.get('editorMode') === 'html') && (baton.model.get('PGPFormat') === 'inline')) {
+                        var dialog2 = new dialogs.CreateDialog({ width: 450, height: 300, center: true });
+                        dialog2.header($('<h4>').text(gt('HTML Formatted Email')));
+                        var warn = $('<p>').append(gt('HTML format is not recommended when using PGP Inline'));
+                        dialog2.getBody().append(warn);
+                        dialog2
+                        .addPrimaryButton('ok', gt('OK'), 'okx')
+                        .show();
+                    }
+                });
             })
             .show();
         });
@@ -110,6 +118,7 @@ define('oxguard/mail/options_new', [
         }
         window.setTimeout (function () {
             createlock(baton);
+            baton.model.dirty(false);
             // If this is a secure reply, then disable all of the options to make it plain text
             if ((window.oxguarddata.action === 'secureReply') || (window.oxguarddata.action === 'fileAttach') || (util.hasEncryptedAttachment(baton) > 0)) {
                 if (window.oxguarddata.replyInline === true) {
@@ -162,9 +171,37 @@ define('oxguard/mail/options_new', [
         baton.model.on('change:PGPFormat', function () {
             warnHTML(baton);
         });
+        baton.model.on('change:PubKey', function () {
+            if (baton.model.get('PubKey')) {
+                attachPubKey (baton);
+            }
+        });
         return;
     }
 
+    // Attach the users public key to the email
+    function attachPubKey (baton) {
+        var attachments = baton.model.get('attachments');
+        for (var i = 0; i < attachments.models.length; i++) {
+            if (attachments.models[i].get('guard') === 'pubkey') {
+                baton.model.set('PubKey', false);
+                return;
+            }
+        }
+        require(['oxguard/mail/pubkey', 'io.ox/core/notifications'], function (pk, notify) {
+            pk.getPubKeyAttachment()
+            .done(function (key) {
+                baton.model.attachFiles(key);
+            })
+            .fail(function () {
+                notify.yell('error', gt('Unable to attach your public key'));
+            })
+            .always(function () {
+                baton.model.set('PubKey', false);
+            });
+        });
+    }
+
     return {
         createOptions: createOptions,
         warnHTML: warnHTML
