@@ -5,21 +5,24 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/mail/oxguard_mail_compose_core', [
     'io.ox/core/extensions',
     'oxguard/core/og_http',
     'io.ox/core/notifications',
     'oxguard/util',
+    'settings!oxguard',
     'io.ox/core/tk/dialogs', 'gettext!oxguard'
-], function (ext, og_http, notify, util, dialogs, gt) {
+], function (ext, og_http, notify, util, settings, dialogs, gt) {
     'use strict';
 
-    var guesticon = '<i id="newguest" class="fa fa-male oxguard_token" style="color:#5DCD55;" title="' + gt('Will create new guest account for Guard') + '"/>';
+    //#. %s product name
+    var guesticon = '<i id="newguest" class="fa fa-male oxguard_token" style="color:#5DCD55;" title="' + gt('Will create new guest account for %s', window.oxguarddata.productName) + '"/>';
     //#. Have encryption key - Shown on icon hover when a key symbol is displayed for recipient.  We/Guard have an encryption key for the recipient.
-    var keyicon = '<i class="fa fa-key oxguard_token oxguard_lock" aria-hidden="true" title="' + gt('Have encryption key') +'"></i>';
-    var failicon = '<i id="newguest" class="fa fa-ban oxguard_token" style="color:red;" title="' + gt('Will create new guest account for Guard') + '"/>';
+    var keyicon = '<i class="fa fa-key oxguard_token oxguard_lock" aria-hidden="true" title="' + gt('Encryption Key Known') +'"></i>';
+    //#. %s product name
+    var failicon = '<i id="newguest" class="fa fa-ban oxguard_token" style="color:red;" title="' + gt('Will create new guest account for %s', window.oxguarddata.productName) + '"/>';
     var prompting = false;
 
     // 7.8 compose code
@@ -56,6 +59,7 @@ define('oxguard/mail/oxguard_mail_compose_core', [
             if (!prompting) {
                 prompting = true;
                 require(['oxguard/oxguard_core'], function (core) {
+                    core.metrics('mail', 'create-keys-from-compose');
                     core.createKeysWizard()
                     .done(function () {
                         checkrecipient(baton);
@@ -80,7 +84,11 @@ define('oxguard/mail/oxguard_mail_compose_core', [
             $('.btn-primary:visible').html(gt('Send'));
         } else {
             var headerview = baton.view.app.get('window').nodes.header;
+            var footerview = baton.view.app.get('window').nodes.footer;
             headerview.find('.btn-primary:visible').html(gt('Send'));
+            if (footerview) {
+                footerview.find('.btn-primary:visible').html(gt('Send'));
+            }
         }
         baton.view.$el.find('.oxguard_key').hide();
         baton.view.$el.find('.oxguard_token').hide();
@@ -101,10 +109,14 @@ define('oxguard/mail/oxguard_mail_compose_core', [
             }
         }
         if (_.device('smartphone')) {
-            $('.btn-primary:visible').html(gt('Send Secure'));
+            $('.btn-primary:visible').html((settings.get('advanced') ? gt ('Send Encrypted') : gt('Send Secure')));
         } else {
             var headerview = baton.view.app.get('window').nodes.header;
-            headerview.find('.btn-primary:visible').html(gt('Send Secure'));
+            var footerview = baton.view.app.get('window').nodes.footer;
+            headerview.find('.btn-primary:visible').html((settings.get('advanced') ? gt ('Send Encrypted') : gt('Send Secure')));
+            if (footerview) {
+                footerview.find('.btn-primary:visible').html((settings.get('advanced') ? gt ('Send Encrypted') : gt('Send Secure')));
+            }
         }
         checkrecipient(baton);
         baton.view.$el.find('.oxguard_key').show();
