@@ -5,7 +5,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 
 define('oxguard/mail/prep_reply', [
@@ -27,12 +27,16 @@ define('oxguard/mail/prep_reply', [
 
     function getForwardHeader (tmp, from, sentDate, textonly) {
         var to = '';
-        for (var i = 0; i < tmp.to.length; i++) {
-            to = to + ' ' + tmp.to[i][0] + ' <' + tmp.to[i][1] + '>';
+        if (tmp.to) {
+            for (var i = 0; i < tmp.to.length; i++) {
+                to = to + ' ' + tmp.to[i][0] + ' <' + tmp.to[i][1] + '>';
+            }
         }
         var cc = '';
-        for (var j = 0; i < tmp.cc.length; i++) {
-            cc = cc + ' ' + tmp.cc[j][0] + ' <' + tmp.cc[j][1] + '>';
+        if (tmp.cc) {
+            for (var j = 0; j < tmp.cc.length; j++) {
+                cc = cc + ' ' + tmp.cc[j][0] + ' <' + tmp.cc[j][1] + '>';
+            }
         }
         var cr = (tmp.replytype.indexOf('html') > 0) ? '<br>' : '\r\n';
         if (textonly === true) cr = '\r\n';
