@@ -5,12 +5,16 @@ define('oxguard/mail/register_compose', [
     'oxguard/mail/oxguard_mail_compose_core',
     'oxguard/util',
     'pgp_mail/toggle-encryption',
+    'io.ox/backbone/mini-views/help',
     'settings!oxguard',
+    'oxguard/mail/mail_metrics',
     'less!pgp_mail/style',
     'less!oxguard/style'
-], function (ext, gt, Dropdown, core, util, ToggleEncryption, settings) {
+], function (ext, gt, Dropdown, core, util, ToggleEncryption, HelpView, settings, metrics) {
     'use strict';
 
+    var sendingSigned = false;
+
     ext.point('io.ox/mail/compose/fields').extend({
         id: 'toggle-encryption',
         index: 'last',
@@ -20,6 +24,8 @@ define('oxguard/mail/register_compose', [
                 var view = new ToggleEncryption.View({
                     model: baton.model
                 });
+                view.noLinkMail(baton.view);
+
                 //HACK: always insert first, since we do not control
                 //other content
                 node.prepend(view.render().$el);
@@ -28,7 +34,7 @@ define('oxguard/mail/register_compose', [
                 if (window.oxguarddata) {
                     if (window.oxguarddata.action === 'secureReply') {
                         if (window.oxguarddata.settings.oxguard === false || window.oxguarddata.settings.secureReply) {
-                            view.forceLock();
+                            view.forceEncryption();
                         } else {
                             baton.model.set('encrypt', true);
                         }
@@ -122,7 +128,6 @@ define('oxguard/mail/register_compose', [
                     if (util.isGuardEnabled()) {
                         drawDropDown (baton, $(node));
                         require (['oxguard/mail/options_new'], function (options) {
-                            console.log(options);
                             options.createOptions(baton);
                         });
                     }
@@ -136,16 +141,37 @@ define('oxguard/mail/register_compose', [
             if (window.oxguarddata.settings.oxguard) {
                 setQuit (baton);  // Set handles for quit function
                 var dropdown = new Dropdown({ model: baton.model, label: gt('Security'), caret: true });
+                if (settings.get('advanced')) {
+                    dropdown
+                        .header(gt('PGP'));
+                } else {
+                    dropdown
+                    .header(gt('Security'));
+                }
                 dropdown
-                    .header(gt('PGP'))
-                    .option('encrypt', true, gt('Encrypt'))
-                    .option('PGPSignature', true, gt('Sign'))
-                    //#. Format of the email, HTML or Plaintext
+                    .option('encrypt', true, (settings.get('advanced') ? gt('Encrypt') : gt('Secure')))
+                    .option('PGPSignature', true, gt('Sign'));
+                if (settings.get('advanced')) {
+                    dropdown
+                  //#. Format of the email, HTML or Plaintext
                     .header(gt('Format'))
                     .option('PGPFormat', 'mime', gt('PGP Mime'))
                     .option('PGPFormat', 'inline', gt('PGP Inline'));
+                    dropdown
+                    .header(gt('Keys'))
+                    .option('PubKey', true, gt('Attach My Key'));
+                }
                 var div = node.find('.col-xs-4');
-                div.append(dropdown.render().$el.addClass('text-left').css('padding-left', '20px'));
+                var dropdownDiv = dropdown.render().$el.addClass('text-left').css('padding-left', '20px');
+                if (!_.device('small')) {
+                    dropdownDiv.find('ul').prepend(new HelpView({
+                        base: 'help-guard',
+                        iconClass: 'guardhelp',
+                        href: 'ox.guard.user.sect.email.send.html',
+                        tabindex: '-1'
+                    }).render().$el.css('float', 'right').css('margin-right', '10px'));
+                }
+                div.append(dropdownDiv);
                 node.find('div[data-extension-id="add_attachments"]').append(div);
             }
         }
@@ -188,9 +214,10 @@ define('oxguard/mail/register_compose', [
                         } else if (action === 'savedraft') {
                             require (['oxguard/mail/sender_compose'], function (sender) {
                                 sender.draftMail(baton, window.oxguarddata.passcode)
-                                .always(function () {
+                                .done(function () {
                                     self.clean();
-                                }).done(def.resolve).fail(def.reject);
+                                    def.resolve();
+                                }).fail(def.reject);
                             });
                         } else {
                             def.reject();
@@ -206,38 +233,22 @@ define('oxguard/mail/register_compose', [
     }
 
     var sendpoint = ext.point('io.ox/mail/compose/buttons');
-    sendpoint.extend({
+    sendpoint.replace({
         id: 'send',
-        index: 100,
         draw: function (baton) {
             this.append($('<button type="button" class="btn btn-primary" data-action="send">')
                 .on('click', function () {
                     if (baton.model.get('encrypt') && util.isGuardEnabled()) {
-                        require (['oxguard/mail/sender_compose'], function (sender) {
-                            var subject = baton.model.get('subject');
-                            if (subject === undefined || subject.trim() === '') {
-                                require(['io.ox/core/tk/dialogs'], function (dialogs) {
-                                    new dialogs.ModalDialog({ focus: false })
-                                        .text(gt('Mail has empty subject. Send it anyway?'))
-                                        .addPrimaryButton('send', gt('Yes, send without subject'), 'send', { tabIndex: 1 })
-                                        .addButton('subject', gt('Add subject'), 'subject', { tabIndex: 1 })
-                                        .show(function () {
-                                        })
-                                        .done(function (action) {
-                                            if (action === 'send') {
-                                                sender.sendMail(baton, window.oxguarddata.passcode);
-                                            } else {
-                                                baton.view.$el.find('input[name="subject"]').focus();
-                                                return;
-                                            }
-                                        });
-                                });
-                            } else sender.sendMail(baton, window.oxguarddata.passcode);
-                        });
+                        if (isReady(baton)) {
+                            doSend(baton);
+                        } else {
+                            waitUntilReady(baton);
+                        }
                     } else {
                         if (baton.model.get('PGPSignature')) { // If for PGP Signature
                             if (!util.isGuardConfigured()) {  // Check if user already set up
                                 require (['oxguard/oxguard_core'], function (core) {
+                                    core.metrics('mail', 'create-keys-for-signature');
                                     core.createKeysWizard()
                                     .done(function () {
                                         sendSigned(baton);
@@ -249,50 +260,126 @@ define('oxguard/mail/register_compose', [
                             }
 
                         } else {
+                            if (baton.model.get('headers') !== undefined) {
+                                baton.model.get('headers')['X-OX-Guard-Marker'] = false;
+                            }
                             baton.view.send();
                         }
                     }
                 })
+                .on('keyup', function (e) {
+                    if ((e.keyCode || e.which) === 27) baton.view.focusEditor();
+                })
                 .text(gt('Send')));
         }
     });
 
+    function isReady (baton) {
+        function checkKey (key) {
+            return (!key.pending);
+        }
+        var keys = baton.model.get('gkeys');
+        return (keys.every(checkKey));
+    }
+
+    // If not all keys returned, wait until completed.
+    // Timeout if no backend response
+    function waitUntilReady (baton) {
+        baton.waiting = true;
+        var win = baton.view.app.getWindow();
+        win.busy();
+        baton.model.on('change:gkeys', function () {
+            if (isReady(baton)) {
+                win.idle();
+                doSend(baton);
+                baton.waiting = false;
+            }
+        });
+        window.setTimeout(function () {
+            if (baton !== undefined) {
+                if (baton.waiting === true) {
+                    win.idle();
+                    baton.waiting = false;
+                    doSend(baton);
+                }
+            }
+        }, 7000);
+    }
+
+    function doSend (baton) {
+        require (['oxguard/mail/sender_compose'], function (sender) {
+            var subject = baton.model.get('subject');
+            if (subject === undefined || subject.trim() === '') {
+                require(['io.ox/core/tk/dialogs'], function (dialogs) {
+                    new dialogs.ModalDialog({ focus: false })
+                        .text(gt('Mail has empty subject. Send it anyway?'))
+                        .addPrimaryButton('send', gt('Yes, send without subject'), 'send', { tabIndex: 1 })
+                        .addButton('subject', gt('Add subject'), 'subject', { tabIndex: 1 })
+                        .show(function () {
+                        })
+                        .done(function (action) {
+                            if (action === 'send') {
+                                sender.sendMail(baton, window.oxguarddata.passcode);
+                            } else {
+                                baton.view.$el.find('input[name="subject"]').focus();
+                                return;
+                            }
+                        });
+                });
+            } else sender.sendMail(baton, window.oxguarddata.passcode);
+        });
+    }
+
+    function addHeader (baton) {
+        var headers = baton.model.get('headers');
+        if (headers === undefined) headers = {};
+        var newheaders = {
+            'X-OX-Guard-Marker': true
+        };
+        var headers = _.extend(headers, newheaders);
+        baton.model.set('headers', headers);
+    }
+
+    // Event if sending email fails and signing, remove auth
+    ox.on('mail:send:fail', function () {
+        if (sendingSigned === true) {
+            require(['oxguard/oxguard_core'], function (ocore) {
+                ocore.removeAuth();
+            });
+        }
+    });
+
     // Send plaintext signed email
     function sendSigned (baton) {
-        if (baton.model.get('headers') === undefined || baton.model.get('headers')['X-OX-Guard-Auth'] === undefined) {// If not already authrized
-            require(['oxguard/oxguard_core', 'oxguard/crypto/encr', 'io.ox/core/notifications'], function (core, encr, notify) {
-                core.getPassword(gt('Please enter your Guard password to sign this email'))  //Get password
-                .done(function (pass) {
-                    core.auth(ox.user_id, pass)  // Verify against backend
-                    .done(function (data) {
-                        if (data.auth.length > 20) {  // If OK, add header and send
-                            var headers = baton.model.get('headers');
-                            if (headers === undefined) headers = {};
-                            var newheaders = {
-                                'X-OX-Guard-Auth': encr.cryptPass(pass),
-                                'X-OX-Guard-Marker': true
-                            };
-                            var headers = _.extend(headers, newheaders);
-                            baton.model.set('headers', headers);
-                            baton.view.send();
-                        } else {
-                            // Otherwise report error
-                            if (data.auth === 'Bad Password') {
-                                notify.yell('error', gt('Bad Password'));
-                            } else {
-                                notify.yell('error', gt('Error') + ' ' + data.auth);
-                            }
-                        }
+        metrics.track('send-plaintext-signed');
+        require(['oxguard/oxguard_core', 'io.ox/core/notifications'], function (ocore, notify) {
+            ocore.checkAuth()
+            .done(function () {
+                addHeader (baton);
+                sendingSigned = true;
+                baton.view.send()
+                .always(function () {
+                    sendingSigned = false;
+                });
+            })
+            .fail(function () {
+                ocore.getPassword(gt('Please enter your %s password to sign this email.', window.oxguarddata.productName), true)  //Get password
+                .done(function (passdata) {
+                    ocore.savePassword(passdata.password, passdata.duration)
+                    .done(function () {
+                        addHeader (baton);
+                        baton.view.send();
                     })
-                    .fail(function () {
-                        notify.yell('error', gt('Unable to authorize against backend'));
+                    .fail(function (data) {
+                        if (data.auth === 'Bad Password') {
+                            notify.yell('error', gt('Bad Password'));
+                        } else {
+                            notify.yell('error', gt('Unable to authorize against backend'));
+                        }
                     });
                 });
             });
-        } else {
-            baton.model.get('headers')['X-OX-Guard-Marker'] = true;
-            baton.view.send();
-        }
+        });
     }
 
     ext.point('io.ox/mail/compose/buttons').replace({
@@ -336,4 +423,5 @@ define('oxguard/mail/register_compose', [
             });
         });
     }
+
 });
