@@ -1,12 +1,15 @@
-define('oxguard/mail/saveattach',
-    ['io.ox/mail/api', 'io.ox/core/http',
-     'io.ox/core/notifications', 'settings!io.ox/core',
-     'io.ox/core/tk/dialogs',
-     'io.ox/core/tk/folderviews',
-     'io.ox/core/api/folder',
-     'settings!io.ox/files', // yep, files not mail!
-     'settings!io.ox/core',
-     'gettext!oxguard/mail/saveattach'], function (api, http, notifications, coreConfig, dialogs, views, folderAPI, settings, settingsCore, gt) {
+define('oxguard/mail/saveattach', [
+    'io.ox/mail/api',
+    'io.ox/core/http',
+    'io.ox/core/notifications',
+    'settings!io.ox/core',
+    'io.ox/core/tk/dialogs',
+    'io.ox/core/tk/folderviews',
+    'io.ox/core/api/folder',
+    'settings!io.ox/files', // yep, files not mail!
+    'settings!io.ox/core',
+    'gettext!oxguard'
+], function (api, http, notifications, coreConfig, dialogs, views, folderAPI, settings, settingsCore, gt) {
 
     'use strict';
 
@@ -60,7 +63,6 @@ define('oxguard/mail/saveattach',
             }
             return (def);
         }
-        
         notifications.yell('busy',
             gt.ngettext('Saving attachment to Drive', 'Saving attachments to Drive', list.length) + ' ...'
         );
@@ -71,7 +73,7 @@ define('oxguard/mail/saveattach',
             folderAPI.reload(target, list);
         }).fail(function (data) {
             if (data == 'Failed to decrypt') {  // Translate known error messages
-                data = gt('Failed to decrypt'); 
+                data = gt('Failed to decrypt');
             }
             if (data == 'Failed to save') { // Generic error, no additional lines needed
                 data = '';
@@ -79,8 +81,6 @@ define('oxguard/mail/saveattach',
             notifications.yell('error', gt('Failed to save attachments') + '\r\n' + data);
         });
     }
-    
-
 
     return {
 
@@ -88,8 +88,8 @@ define('oxguard/mail/saveattach',
 
             var dialog = new dialogs.ModalDialog()
                 .header($('<h4>').text('Save attachment'))
-                .addPrimaryButton('ok', gt('Save'), 'ok', {tabIndex: '1'})
-                .addButton('cancel', gt('Cancel'), 'cancel', {tabIndex: '1'});
+                .addPrimaryButton('ok', gt('Save'), 'ok', { tabIndex: '1' })
+                .addButton('cancel', gt('Cancel'), 'cancel', { tabIndex: '1' });
 
             dialog.getBody().css({ height: '250px' });
 
@@ -126,4 +126,4 @@ define('oxguard/mail/saveattach',
             });
         }
     };
-});
\ No newline at end of file
+});
