@@ -5,7 +5,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 
 define('oxguard/mail/sender_compose', [
@@ -13,8 +13,9 @@ define('oxguard/mail/sender_compose', [
     'oxguard/mail/util',
     'oxguard/mail/keymanager',
     'oxguard/crypto/encr',
+    'oxguard/mail/mail_metrics',
     'gettext!oxguard'
-], function (ext, util, keyman, encr, gt) {
+], function (ext, util, keyman, encr, metrics, gt) {
 
     'use strict';
 
@@ -60,6 +61,7 @@ define('oxguard/mail/sender_compose', [
                 '&sentfolder=' + encodeURIComponent(window.oxguarddata.sentfolder) +
                 '&draftfolder=' + encodeURIComponent(window.oxguarddata.draftfolder) +
                 '&draft=' + (draft ? 'true' : 'false') +
+                (window.oxguarddata.passcode !== null ? ('&auth=' + encodeURIComponent(window.oxguarddata.passcode)) : '') +
                 '&lang=' + ox.language + (guestdata === null ? '' : ('&guestlanguage=' + guestdata.language)) +
                 ((secure_reply === undefined) ? '' : ('&sr=' + secure_reply));
             if (baton.model.get('PGPSignature') && !draft) {
@@ -130,6 +132,17 @@ define('oxguard/mail/sender_compose', [
         spinRefresh();
         getFiles(baton, mail, auth, guestdata, pass, draft)
         .done(function (result) {
+            if (result.indexOf('error') > -1) {
+                require(['oxguard/oxguard_core'], function (core) {
+                    core.handleErrorHTML (result);
+                    return;
+                });
+                def.reject('fail');
+                stopSpinRefresh();
+                win.idle().show();
+                return;
+            }
+            baton.view.model.dirty(false);
             if (draft) {
                 require (['io.ox/core/notifications'], function (notifications) {
                     notifications.yell('success', gt('Mail saved as draft'));
@@ -146,6 +159,7 @@ define('oxguard/mail/sender_compose', [
                 baton.view.isSaving = false;
                 def.resolve('OK');
             } else {
+                baton.view.stopListening(baton.view.model, 'needsync', baton.view.syncMail);
                 baton.view.app.quit();
             }
             stopSpinRefresh();
@@ -153,17 +167,39 @@ define('oxguard/mail/sender_compose', [
         .fail(function (r) {
             stopSpinRefresh();
             win.idle().show();
+            win.app.launch();
+            var error = '';
+            switch (r) {
+            case 'keyproblem':
+                error = gt('Unable to get keys for all users');
+                break;
+            case 'missingUID':
+                error = gt('The from address you selected for this email is not associated with an encryption key.  Please send from your primary account, or optionally, add the email address to your key using the advanced settings.');
+                break;
+            default:
+                error = r;
+            }
+            // If it was sent with auth code, and no longer valid, try resend without password for prompting.
+            if ((r.indexOf('password') > 0) && window.oxguarddata.passcode && window.oxguarddata.passcode.length > 20) {
+                window.oxguarddata.passcode = null;
+                send(baton, null, guestdata, undefined, draft);
+                return;
+            }
             require (['io.ox/core/notifications'], function (notifications) {
                 if (draft) {
-                    notifications.yell('error', gt('An error occurred saving the email.') + ' ' + r);
+                    notifications.yell('error', gt('An error occurred saving the email.') + ' ' + error);
                     baton.view.isSaving = false;
                     def.reject('fail');
-                } else
-                    notifications.yell('error', gt('An error occurred during sending the encrypted email.') + ' ' + r);
+                } else {
+                    if (r.indexOf('password') > 0) {
+                        notifications.yell('error', gt('Bad Password'));
+                    } else {
+                        notifications.yell('error', gt('An error occurred sending the encrypted email.') + ' ' + error);
+                    }
+                }
+
             });
         });
-        baton.view.stopListening(baton.view.model, 'needsync', baton.view.syncMail);
-        baton.view.model.dirty(false);
         if (draft) {
             return (def);
         }
@@ -211,40 +247,66 @@ define('oxguard/mail/sender_compose', [
 
     // Check for password need.  Signature returns 2, encrypted file 3.  Old Guard with extrapass 1
     function checkPasswordNeeded(baton) {
-        if (baton.model.get('PGPSignature')) return 2;
+        if (baton.model.get('PGPSignature')) {
+            metrics.track('encrypted-with-signature');
+            if (window.oxguarddata.passcode === null || (window.oxguarddata.passcode && window.oxguarddata.passcode.length < 20))
+            return 2;
+        }
         return (util.hasEncryptedAttachment(baton));
     }
 
+    // Prompt for password for signing.  Offer to save and register if needed
+    function getPasswordForSigning(baton, auth, data) {
+        require (['oxguard/oxguard_core'], function (core) {
+            core.getPassword(gt('Please enter your %s password to sign this email.', window.oxguarddata.productName), true)
+            .done(function (passData) {
+                var pass = {
+                        password: passData.password,
+                        extrapass: ''
+                    };
+                if (passData.duration < 0) {  // Just send, no remembering password
+                    send(baton, auth, data, pass);
+                } else {
+                    core.savePassword(passData.password, passData.duration)
+                    .done(function (authData) {
+                        send(baton, authData.auth, data, pass);
+                    })
+                    .fail(function (authData) {
+                        if (authData.auth === 'Bad Password') {
+                            require (['io.ox/core/notifications'], function (notifications) {
+                                notifications.yell('error', gt('Bad Password'));
+                            });
+                        }
+                    });
+                }
+            });
+            stop(baton);
+        });
+    }
+
     function getPassword(baton, auth, data, level) {
+        if (level == 2) { //PGP Siging
+            getPasswordForSigning(baton, auth, data);
+            return;
+        }
+        // Password required for attachmnets.  Prompt
         require (['io.ox/core/tk/dialogs'], function (dialogs) {
             var dialog = new dialogs.CreateDialog({ width: 490, center: true,  enter: 'ok' });
             dialog.header($('<h4>').text(gt('Password Needed')));
-            var help = '';
-            if (level === 2) { // PGP signing email
-                help = $('<p>' + gt('Please enter your Guard password for signing') + '</p>');
-            } else {
-                help = $('<p>' + gt('At least one of your attachments are encrypted.  Please provide your Guard Security Password to decrypt before sending') + '</p>');
-            }
-            var pass = $('<input name="password" id="password" type="password"/>');
-            dialog.getBody().append(help).append(pass);
-            if (level == 1) { // Attachment with extra password
-                var extrapasshelp = $('<p style="padding-top:5px;">' + gt('Extra Password') + '</p>');
-                var extra = $('<input name="extrapass" id="atextrapass" type="password"/>');
-                dialog.getBody().append(extrapasshelp).append(extra);
-            }
+            var help = $('<p>' + gt('At least one of your attachments are encrypted.  Please provide your %s Security Password to decrypt before sending', window.oxguarddata.productName) + '</p>');
+            var noSaveWorkAround = $('<input style="display:none" type="text" name="dontremember"/><input style="display:none" type="password" name="dontrememberpass"/>');
+            var pass = $('<input name="password" id="password" type="password" autocomplete="off"/>');
+            dialog.getBody().append(help).append(noSaveWorkAround).append(pass);
             dialog.addPrimaryButton('ok', gt('OK'), 'ok')
             .on('ok', function () {
-                var extrap = $('#atextrapass').val();
                 var pass = {
                     password: $('#password').val(),
-                    extrapass: (extrap === undefined) ? '' : extrap
+                    extrapass: ''
                 };
                 send(baton, auth, data, pass);
             })
             .on('cancel', function () {
-                stopSpinRefresh();
-                var win = baton.view.app.getWindow();
-                win.idle().show();
+                stop(baton);
             });
             dialog.show(function () {
                 if (!_.device('ios')) {
@@ -254,6 +316,12 @@ define('oxguard/mail/sender_compose', [
             });
         });
     }
+
+    function stop(baton) {
+        stopSpinRefresh();
+        var win = baton.view.app.getWindow();
+        win.idle().show();
+    }
     // Display options for guest account header (introduction)
     function guestOptions(baton, auth) {
 
@@ -263,7 +331,7 @@ define('oxguard/mail/sender_compose', [
             var help = $('<p>' + gt('At least one of your recipients uses a different webmail system.  They will receive an email with a link for them to read this message.  If you like, you can add a personalized message that will appear at the top of this message.  This will help identify the message as coming from you.') + '</p>');
             var messageLabel = $('<label class="oxguard_message_label">' + gt('Message:') + '</label>');
             var message = $('<textarea type="text" id="message" class="og_guest_message"></textarea>');
-            var languageLabel = $('<br/><label>' + gt('Automated Email Language') + '</label>');
+            var languageLabel = $('<br/><label style="width:100%; padding-top:10px;">' + gt('Language for recipient Email') + '</label>');
             var langselect = $('<select class="og_language"></select>');
             // Populate language selector with languages avail
             var languages = window.oxguarddata.lang;
@@ -278,6 +346,11 @@ define('oxguard/mail/sender_compose', [
                     message: message.val(),
                     language: langselect.val()
                 };
+                if (message.val() && message.val().length > 1) {
+                    metrics.track('guest-email-message');
+                } else {
+                    metrics.track('guest-email-no-message');
+                }
                 // Check if requires PIN to be displayed
                 require(['oxguard/mail/pin', 'io.ox/core/capabilities'], function (pin, capabilities) {
                     if (capabilities.has('guard-pin')) {
@@ -308,17 +381,11 @@ define('oxguard/mail/sender_compose', [
 
     return {
         sendMail: function sendmail(baton, auth) {
-            require(['io.ox/metrics/main'], function (metrics) {
-                metrics.trackEvent({
-                    app: 'mail',
-                    target: 'compose/toolbar',
-                    type: 'click',
-                    action: 'send-secure'
-                });
-            });
+            metrics.track('send-secure');
             send(baton, auth, null, undefined, false);
         },
         draftMail: function draftmail(baton, auth) {
+            metrics.track('encrypted-draft');
             saveDraftInfo(baton);
             return (send (baton, auth, null, undefined, true));
         }
