@@ -5,7 +5,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/oxguard_core', [
     'settings!io.ox/mail',
@@ -49,22 +49,24 @@ define('oxguard/oxguard_core', [
                 this.trigger('send send:error', this.validationError);
                 return;
             }
-            og_http.post(ox.apiRoot + '/oxguard/login?action=create', '&session=' + ox.session + (this.get('initialSetup') ? '' : '&add=true'), this.toJSON())
+            og_http.post(ox.apiRoot + '/oxguard/login?action=create', (this.get('initialSetup') ? '' : '&add=true'), this.toJSON())
             .done(function (data) {
                 if (data.indexOf('ok') > 0) {
                     window.oxguarddata.passcode = null;
+                    window.oxguarddata.recoveryAvail = window.oxguarddata.recovery = !window.oxguarddata.settings.noRecovery;
                     self.trigger('send send:ok');
                     self.set('sent', true);
+                    if (window.oxguarddata.recovery) window.oxguarddata.recoveryAvail = true;
                 } else {
-                    self.trigger('send send:error', gt('Problems creating keys, please try again later'));
+                    self.trigger('send send:error', gt('Problems creating keys, please try again later.'));
                 }
             })
             .fail(function (data) {
                 var error;
                 if (data.responseText.trim() === 'Existing') {
-                    error = gt('Problems creating keys.  Keys already exist for this email address in another account');
+                    error = gt('Problems creating keys.  Keys already exist for this email address in another account.');
                 } else {
-                    error = gt('Problems creating keys, please try again later');
+                    error = gt('Problems creating keys, please try again later.');
                 }
                 self.trigger('send send:error', error);
             });
@@ -176,8 +178,8 @@ define('oxguard/oxguard_core', [
 
         renderDescription: function (el) {
             el.append($('<div>').append(
-                this.model.get('initialSetup') ? $('<p>').text(gt('This appears to be the first time you have used Encryption')) : '',
-                $('<p>').text(gt('Please enter a password to protect your new encrypted items'))
+                this.model.get('initialSetup') ? $('<p>').text(gt('Please choose the password you will use for %s. You will need to type this password whenever you want to encrypt or decrypt items. Remember it should be different from your login password, and will not change if you change your login password.', window.oxguarddata.productName)) : '',
+                $('<p>').text(gt('Please enter a password to protect your new encrypted items.'))
             ));
             return this;
         },
@@ -188,7 +190,7 @@ define('oxguard/oxguard_core', [
                         .addClass('col-sm-12 col-md-4 control-label')
                         .text(gt('Password')),
                     $('<div>').addClass('col-sm-12 col-md-8').append(
-                        $('<input name="newogpassword" type="password"/>').addClass('form-control')
+                        $('<input name="newogpassword" type="password" autocomplete="off"/>').addClass('form-control')
                     ),
                     $('<div>').addClass('col-sm-12 error-msg')
                 ),
@@ -197,7 +199,7 @@ define('oxguard/oxguard_core', [
                         .addClass('col-sm-12 col-md-4 control-label')
                         .text(gt('Confirm')),
                     $('<div>').addClass('col-sm-12 col-md-8').append(
-                        $('<input name="newogpassword2" type="password"/>').addClass('form-control')
+                        $('<input name="newogpassword2" type="password" autcomplete="off"/>').addClass('form-control')
                     ),
                     $('<div>').addClass('col-sm-12 error-msg')
                 )
@@ -205,11 +207,15 @@ define('oxguard/oxguard_core', [
             return this;
         },
         renderRecoverMailPrompt: function (el) {
-            if (window.oxguarddata.settings.noRecovery === true) return this;  // If no recovery set, don't add prompt for second password
+            if (window.oxguarddata.settings.noRecovery === true) {
+                el.append($('<hr style="padding:10px;"/>'),
+                        $('<p class="oxguard_warning">').text(gt('Warning: This password for encryption cannot be restored or recovered in any way.  If forgotten, all encrypted data will be lost')));
+                return this;  // If no recovery set, don't add prompt for second password
+            }
             if (this.model.get('initialSetup')) {
                 el.append(
                     $('<hr style="padding:10px;"/>'),
-                    $('<p>').text(gt('Please enter a secondary email address in case you need to reset your password')),
+                    $('<p>').text(gt('Please enter a secondary email address in case you need to reset your password.')),
                         $('<div>').addClass('form-group email').append(
                         $('<label>').addClass('col-sm-12 col-md-4 control-label').text(gt('Email:')),
                         $('<div>').addClass('col-sm-12 col-md-8').append(
@@ -259,7 +265,8 @@ define('oxguard/oxguard_core', [
         require (['io.ox/core/notifications', 'io.ox/core/tk/dialogs'], function (notify, dialogs) {
 
             var dialog = new dialogs.CreateDialog({ width: 450, center: true, enter: 'ok', async: true });
-            dialog.header($('<h4>').text(gt('Create Guard Security Keys')));
+            //#. %s product name
+            dialog.header($('<h4>').text(gt('Create %s Security Keys', window.oxguarddata.productName)));
             dialog.getBody().append(view.render().$el);
 
             dialog
@@ -304,140 +311,12 @@ define('oxguard/oxguard_core', [
         return def;
     }
 
-    /// First time OG users or has had password reset
-    /// This is referred to for Guard proprietary check
-    /// Can likely be removed in near future
-    function createOxGuardPasswordPrompt(baton, errors, oldpass, goFunction)
-    {
-        require (['io.ox/core/tk/dialogs'], function (dialogs) {
-            var dialog = new dialogs.ModalDialog({ width: 450, center: true, enter: 'okpass' });
-            dialog.header($('<h4>').text(gt('First Guard Security Password Use')));
-            var explain = $('<div><p>' + gt('Please change the temporary Guard security password that was sent to you in a seperate email.') + '</p></div>');
-
-            var passdiv = $('<div>').addClass('row-fluid');
-            var newogpassword = $('<input name="newogpassword" type="password"/>');
-            var td1 = $('<td>').append(newogpassword);
-            var newogpassword2 = $('<input name="newogpassword2" type="password"/>');
-            var td2 = $('<td>').append(newogpassword2);
-            var hint = $('<td>');
-            var table = $('<table class="og_password_prompt"/>')
-            .append('<tr><td class="pw"><em>' + gt('Initial Password') + ':</em></td><td><input name="oldogpassword" type="password"/></td></tr>')
-            .append($('<tr><td class="pw"><em>' + gt('New Password') + ':</em></td></tr>').append(td1).append(hint))
-            //#. Confirm new password
-            .append($('<tr><td class="pw"><em>' + gt('Confirm New') + ':</em></td></tr>').append(td2).append('<td></td>'));
-            passdiv.append(table);
-            dialog.getBody().append(explain).append(passdiv);
-            require (['oxguard/core/passwords'], function (pass) {
-                pass.passwordCheck(newogpassword, hint);
-                pass.passwordCompare(newogpassword2, newogpassword, hint);
-            });
-            var rule = $('<hr style="padding:10px;"/>');
-            var recovery = $('<p>' + gt('Please enter a secondary email address in case you need to reset your password' + '</p>'));
-
-            var table2 = $('<table class="og_password_prompt"/>');
-            var row = $('<tr><td class="pw"><em>' + gt ('Email:') + '</em></td><td><input name="recoveryemail"/></td></tr>');
-            table2.append(row);
-            dialog.getBody().append(rule).append(recovery).append(table2);
-
-            if (errors !== undefined) {
-                dialog.getBody().append('<div><span style="color: red;">' + errors + '</span></div>');
-            }
-            dialog
-            .addPrimaryButton('okpass', gt('OK'), 'okpass')
-            .addButton('cancel', gt('Cancel'), 'cancel')
-            .on('okpass', function () {
-                var oldpass = $('input[name="oldogpassword"]').val();
-                var pass1 = $('input[name="newogpassword"]').val();
-                var pass2 = $('input[name="newogpassword2"]').val();
-                var emailaddr = $('input[name="recoveryemail"]').val();
-                if (pass1 !== pass2) {
-                    $('input[name="newogpassword2"]').css('background-color', 'salmon');
-                    createOxGuardPasswordPrompt(baton, gt('Passwords not equal'), oldpass, goFunction);
-                    return;
-                }
-                var userdata = {
-                    newpass: pass1,
-                    oldpass: oldpass,
-                    email: emailaddr,
-                    user_id: ox.user_id,
-                    sessionID: ox.session,
-                    cid: ox.context_id
-                };
-                if ((emailaddr.length > 1) && (!validateEmail(emailaddr))) {
-                    createOxGuardPasswordPrompt(baton, gt('Enter new secondary Email address'), oldpass, goFunction);
-                    return;
-                }
-                if (validateEmail(emailaddr)) userdata.email = emailaddr;
-                require (['io.ox/core/notifications', 'oxguard/mail/oxguard_mail', 'oxguard/core/og_http'], function (notifications, oxmail, og_http) {
-                    og_http.post(ox.apiRoot + '/oxguard/login?action=changepass', '&session=' + ox.session, userdata)
-                    .done(function (data) {
-                        if (typeof data === 'string') data = $.parseJSON(data);
-                        if (data.auth.length > 20) {
-                            $('#grdsettingerror').text(gt('Success'));
-                            $('input[name="newogpassword"]').val('');
-                            $('input[name="newogpassword2"]').val('');
-                            window.oxguarddata.passcode = null;
-                            if (goFunction !== undefined) goFunction (baton, data);
-                            notifications.yell('success', gt('Password changed successfully'));
-                        } else {
-                            if (data.auth === 'Bad new password') {
-                                notifications.yell('error', gt('New password must be at least %s characters long', data.minlength));
-                                return;
-                            }
-                            if (data.auth === 'Bad password') {
-                                //#. Bad, incorrect password
-                                notifications.yell('error', gt('Bad password'));
-                                return;
-                            }
-                            if (data.auth === 'Key not found') {
-                                notifications.yell('error', gt('Encryption key not found'));
-                                return;
-                            }
-                            notifications.yell('error', gt('Failed to change password'));
-                        }
-                    })
-                    .fail(function () {
-                        notifications.yell('error', gt('Failed to change password'));
-                    });
-                });
-            })
-            .show(function () {
-                if (oldpass !== undefined) {
-                    $('input[name="oldogpassword"]').val(oldpass);
-                    if (!_.device('ios')) {
-                        $('input[name="newogpassword"]').focus();
-                    }
-                } else
-                    if (!_.device('ios')) {
-                        $('input[name="oldogpassword"]').focus();
-                    }
-                window.setTimeout(function () {
-                    var j = 0;
-                    $('.pw').each(function (i,v) {
-                        var w = $(v).width();
-                        if (w > j) j = w;
-                    });
-                    $('.pw').each(function (i,v) {
-                        $(v).width(j);
-                    });
-                    var email = $('input[name="recoveryemail"]'); // Watch email entry for valid
-                    email.on('keyup', function () {
-                        if (validateEmail(email.val())) {
-                            email.css('background-color', 'white');
-                        } else {
-                            email.css('background-color', 'rgb(253, 187, 179)');
-                        }
-                    });
-                },0);
-            });
-        });
-    }
-
     function validateEmail(email) {
         var re = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
         return re.test(email);
     }
 
+    // Unified inbox combines folder and email ID, returns email id
     function getId(baton) {
         var id = decodeURIComponent(baton.data.id);
         try {
@@ -450,77 +329,84 @@ define('oxguard/oxguard_core', [
         baton.view.loaded = true;
         window.oxguarddata.priv = undefined;
         var eid = getId(baton);
-        var retry = false;
+        var errorResponse = {
+            retry: false,
+            errorMessage: 'Fail'
+        };
         if (data.status == 503) {
-            baton.view.$el.find('#error' + eid).replaceWith('<div class="error" id="error' + eid + '"><br>' + gt('Unable to connect to the encryption server.') + '</hr></div>');
+            showError (baton, gt('Unable to connect to the encryption server.'), eid);
         } else {
-            var errorMessage = 'Fail';
-            var resp = data.responseText.split(':');
-            switch (resp[0].trim()) {
-            case 'noitem':
-                errorMessage = gt('Unable to find the item on the server');
-                break;
-            case 'nocc':
-                errorMessage = gt('Unable to get the key for that item');
-                break;
-            case 'nokey':
-                errorMessage = gt('Unable to retrieve your user keys to decode');
-                break;
-            case 'Bad extra':
-                errorMessage = gt('Bad extra password');
-                retry = true;
-                break;
-            case 'No Private Key associated with the Public Key':
-                errorMessage = gt('No private key to decode this message');
-                retry = false;
-                break;
-            case 'Bad Password':
-                errorMessage = gt('Unable to decrypt Email, incorrect password.');
-                require (['io.ox/core/notifications'], function (notifications) {
-                    notifications.yell('error', gt('Bad password'));
-                });
-                badCount++;
-                if (badCount > 2) {
-                    var url = document.URL;
-                    errorMessage += ('<br/>' + gt('To reset or recover your password, click %s', '<a id="guardsettings" href="' + url + '">' + gt('Settings') + '</a>'));
-                }
-                retry = true;
-                break;
-            case 'No secret key':
-                errorMessage = gt('No Private Key available for this encrypted item.') + (resp[1] !== undefined ? ('<br>' + gt('Key Ids:') + resp[1]) : '');
-                retry = false;
-                break;
-            case 'Exceeded':
-                errorMessage = gt('Your account is locked out for %s minutes', resp[1]);
-                retry = false;
-                break;
-            case 'Error':
-                errorMessage = gt('Error');
-                retry = false;
-                break;
-            default:
-                console.log(resp);
-                errorMessage = gt('Unable to decrypt Email, incorrect password.');
-                retry = true;
-                break;
-            }
-            if (data.status == 500) errorMessage = gt('Server Error: ') + data.responseText.trim();
-            baton.view.$el.find('#error' + eid).replaceWith('<div class="error" id="error' + eid + '"><br>' + errorMessage + '</hr></div>');
-            if (badCount > 2) {
-                baton.view.$el.find('#guardsettings').click(function (e) {
-                    ox.launch('io.ox/settings/main', { id: 'oxguard' }).done(function () {
-                        this.setSettingsPane({ id: 'oxguard' });
+            if (data.code !== undefined) {
+                handleJsonError (data, errorResponse, baton);
+            } else {
+                var resp = data.responseText.split(':');
+                switch (resp[0].trim()) {
+                case 'noitem':
+                    errorResponse.errorMessage = gt('Unable to find the item on the server');
+                    break;
+                case 'nocc':
+                    errorResponse.errorMessage = gt('Unable to get the key for that item');
+                    break;
+                case 'nokey':
+                    errorResponse.errorMessage = gt('Unable to retrieve your user keys to decode');
+                    break;
+                case 'Bad extra':
+                    errorResponse.errorMessage = gt('Bad extra password');
+                    errorResponse.retry = true;
+                    break;
+                case 'No Private Key associated with the Public Key':
+                    errorResponse.errorMessage = gt('No private key to decode this message');
+                    errorResponse.retry = false;
+                    break;
+                case 'Bad Password':
+                    errorResponse.errorMessage = gt('Unable to decrypt Email, incorrect password.');
+                    require (['io.ox/core/notifications'], function (notifications) {
+                        notifications.yell('error', gt('Bad password'));
                     });
-                    e.preventDefault();
-                });
+                    badCount++;
+                    if (badCount > 2 && window.oxguarddata.recoveryAvail) {
+                        errorResponse.errorMessage += ('<br/>' + gt('To reset or recover your password, click %s', '<a id="guardsettings" href="#">' + gt('Settings') + '</a>'));
+                    }
+                    errorResponse.retry = true;
+                    break;
+                case 'No secret key':
+                    errorResponse.errorMessage = gt('No Private Key available for this encrypted item.') + (resp[1] !== undefined ? ('<br>' + gt('Key Ids:') + resp[1]) : '');
+                    errorResponse.retry = false;
+                    break;
+                case 'Exceeded':
+                    errorResponse.errorMessage = gt('Your account is locked out for %s minutes', resp[1]);
+                    errorResponse.retry = false;
+                    break;
+                case 'Error':
+                    errorResponse.errorMessage = gt('Error');
+                    errorResponse.retry = false;
+                    break;
+                default:
+                    errorResponse.errorMessage = gt('Unable to decrypt Email, incorrect password.');
+                    errorResponse.retry = true;
+                    break;
+                }
             }
+
+            if (data.status == 500) errorResponse.errorMessage = gt('Server Error: ') + data.responseText.trim();
+
         }
-        if (retry) {
+        if (errorResponse.retry) {
             require (['oxguard/mail/oxguard_mail'], function (og_mail) {
                 baton.view.$el.find('#content' + eid).replaceWith(og_mail.passwordPrompt(baton, true, undefined, goFunction));
+                showErrorOld (baton, errorResponse.errorMessage, eid);
+                if (badCount > 2) {
+                    baton.view.$el.find('#guardsettings').click(function (e) {
+                        ox.launch('io.ox/settings/main', { id: 'oxguard' }).done(function () {
+                            this.setSettingsPane({ id: 'oxguard' });
+                        });
+                        e.preventDefault();
+                    });
+                }
             });
             baton.view.$el.find('.body').show();
         } else {
+            showErrorOld (baton, errorResponse.errorMessage, eid);
             $('.content').hide();
         }
         try {// blank out auth if present
@@ -529,17 +415,98 @@ define('oxguard/oxguard_core', [
         deferred.reject('error');
     }
 
-    function getpassword (message) {
+    function showErrorOld (baton, error, eid) {
+        baton.view.$el.find('#error' + eid).replaceWith('<div class="oxguard_error" id="error' + eid + '"><br>' + error + '</hr></div>');
+    }
+
+    function handleJsonError (error, errorResponse, baton) {
+        errorResponse.errorMessage = gt('Error');
+        errorResponse.retry = false;
+        if (error.code !== undefined) {
+            switch (error.code) {
+                case 'GRD-PGP-0005':
+                    if (window.oxguarddata.passcode && (window.oxguarddata.passcode.length > 20)) {  // If bad password based on auth, then clear auth and redo
+                        window.oxguarddata.passcode = null;
+                        if (baton) baton.view.redraw();
+                        return;
+                    }
+                    errorResponse.errorMessage = gt('Unable to decrypt Email, incorrect password.');
+                    require (['io.ox/core/notifications'], function (notifications) {
+                        notifications.yell('error', gt('Bad password'));
+                    });
+                    badCount++;
+                    if (badCount > 2 && window.oxguarddata.recoveryAvail) {
+                        errorResponse.errorMessage += ('<br/>' + gt('To reset or recover your password, click %s', '<a id="guardsettings" href="#">' + gt('Settings') + '</a>'));
+                    }
+                    errorResponse.retry = true;
+                    break;
+                default:
+                    if (error.error !== undefined) {
+                        errorResponse.errorMessage = error.error;
+                    }
+            }
+
+        }
+    }
+
+    function showError (errorJson) {
+        var errorResp = {};
+        try {
+            handleJsonError (errorJson, errorResp);
+        } catch (e) {
+            errorResp.errorMessage = gt('Unspecified error');
+        }
+        require (['io.ox/core/notifications'], function (notifications) {
+            notifications.yell('error', errorResp.errorMessage);
+        });
+
+    }
+
+    // Parse the error JSON from an HTML returned error message
+    function handleErrorHTML (error) {
+        var i = error.indexOf('{');
+        if (i >= 0) {
+            var j = error.indexOf('}', i);
+            if (j > 0) {
+                var jsonString = error.substring(i, j + 1);
+                var json = JSON.parse(jsonString);
+                showError (json);
+            }
+        }
+    }
+
+    function getpassword (message, timeOption) {
         var def = $.Deferred();
-        require (['io.ox/core/tk/dialogs'], function (dialogs) {
+        require (['io.ox/core/tk/dialogs', 'oxguard/passwords'], function (dialogs, passwords) {
             var dialog = new dialogs.CreateDialog({ width: 490, center: true,  enter: 'ok' });
             dialog.header($('<h4>').text(gt('Password Needed')));
-            var help =  $('<p>' + gt('Please enter your Guard password') + '</p>');
+            var noSaveWorkAround = $('<input style="display:none" type="text" name="dontremember"/><input style="display:none" type="password" name="dontrememberpass"/>');
+            //#. %s product name
+            var help =  $('<p>' + gt('Please enter your %s password', window.oxguarddata.productName) + '</p>');
             if (message !== undefined) {
                 help = $('<p>' + message + '</p>');
             }
-            var pass = $('<input name="password" id="password" type="password"/>');
-            dialog.getBody().append(help).append(pass);
+            var pass = passwords.createPasswordInput('password');
+            dialog.getBody().append(help).append(noSaveWorkAround).append(pass);
+            if (timeOption) {
+                var remembertext = $('<span class="selectable">&nbsp ' + gt('Remember my password') + '</span>');
+                var rememberpass = $('<div><input type="checkbox" name="rememberpass" value="true" style="margin-top:20px;vertical-align:text-bottom;margin-bottom:1px;"/></div>');
+                var duration = $('<select id="duration" class="og_duration"><option value="10">' + gt('10 minutes') + '</option>' +
+                        '<option value="20">' + gt('20 minutes') + '</option>' +
+                        '<option value="30">' + gt('30 minutes') + '</option>' +
+                        '<option value="60">' + gt('1 hour') + '</option>' +
+                        '<option value="120">' + gt('2 hours') + '</option>' +
+                        '<option value="99999">' + gt('Session') + '</option' +
+                        '</select>')
+                        .on('change', function () {
+                            $('input[name="rememberpass"]').prop('checked', true);
+                        });
+                rememberpass.append(remembertext).append(duration);
+                remembertext.click(function () {
+                    $('[name="rememberpass"]').click();
+                });
+                dialog.getBody().append(rememberpass);
+            }
             dialog.addPrimaryButton('ok', gt('OK'), 'ok')
             .on('ok', function () {
             })
@@ -548,43 +515,155 @@ define('oxguard/oxguard_core', [
                 def.reject('cancel');
             })
             .on('ok', function () {
-                def.resolve($('#password').val());
+                var duration = -1;
+                if ($('input[name="rememberpass"]').is(':checked')) {
+                    duration = $('#duration').val();
+                }
+                var data = {
+                    password: $('#password').val(),
+                    duration: duration
+                };
+                def.resolve(data);
             })
             .show(function () {
-                pass.focus();
+                window.setTimeout(function () {
+                    pass.focus();
+                }, 500);
             });
         });
         return (def);
     }
 
+    function sanitize (data) {
+        var regex = new RegExp('<(?:!--(?:(?:-*[^->])*--+|-?)|script\\b(?:[^"\'>]|"[^"]*"|\'[^\']*\')*>[\\s\\S]*?</script\\s*|style\\b(?:[^"\'>]|"[^"]*"|\'[^\']*\')*>[\\s\\S]*?</style\\s*|/?[a-z](?:[^"\'>]|"[^"]*"|\'[^\']*\')*)>', 'gi');
+        return (data.replace(regex, ''));
+    }
+
+    function saveAuthToSession (auth, time) {
+        var def = $.Deferred();
+        var url = ox.apiRoot + '/guard-json?action=auth-token';
+        var params = '';
+        var authToken = {
+            auth: auth,
+            minutesValid: (time === undefined ? -1 : time)
+        };
+        if (auth === null) authToken = {};
+        if (time !== undefined) {
+            authToken.minutesValid = time;
+        }
+        og_http.put (url, params, authToken)
+        .done (function (data) {
+            def.resolve(data);
+        })
+        .fail(function () {
+            def.reject();
+        });
+        return def;
+    }
+
+    function removeAuth() {
+        window.oxguarddata.passcode = null;
+        return saveAuthToSession('');
+    }
+
+    // Save a password in both auth code and token
+    function savePassword (password, duration) {
+        var def = $.Deferred();
+        authorize(ox.user_id, password)
+        .done(function (data) {
+            if (data.auth.length > 20) {
+                if (duration > -1) {  // -1 is only this event, don't remember
+                    window.oxguarddata.passcode = data.auth;
+                    var time = duration * 1000 * 60;
+                    window.setTimeout(function () {
+                        window.oxguarddata.passcode = null;
+                    }, time);
+                }
+                if (duration > 9999) duration = 0;  // 0 for session
+                saveAuthToSession (data.auth, duration)
+                .done (function () {
+                    def.resolve(data);
+                })
+                .fail (function () {
+                    def.reject(data);
+                });
+            } else {
+                def.reject(data);
+            }
+        })
+        .fail (function (e) {
+            def.reject(e);
+        });
+        return def;
+    }
+
+    function checkAuth () {
+        var def = $.Deferred();
+        var url = ox.apiRoot + '/guard-json?action=auth-token';
+        og_http.get (url, '')
+        .done (function (data) {
+            if (data.data === undefined) {
+                def.reject('none');
+                return;
+            }
+            data = data.data;
+            if (data.minutesValid !== undefined) {
+                if (data.minutesValid >= 0) {
+                    def.resolve('ok'); // OK only if exists and still time left.
+                    return;
+                }
+            }
+            def.reject('exp');
+        })
+        .fail (function (e) {
+            console.log(e);
+            def.reject('fail');
+        });
+        return def;
+    }
+
+    function authorize(userid, password, extra, keyid)
+    {
+        var def = $.Deferred();
+        var defaultSendAddress = $.trim(settings.get('defaultSendAddress', ''));
+        var userdata = {
+            user_id: userid,
+            ox_password: password,
+            encr_password: '',
+            sessionID: ox.session,
+            lang: ox.language,
+            cid: ox.context_id,
+            email: defaultSendAddress,
+            extrapass: extra ? extra : ''
+        };
+        var url = ox.apiRoot + '/oxguard/login?action=login';
+        var params = '&time=' + new Date().getTime();
+        if (keyid !== undefined) params += '&keyid=' + keyid;
+        og_http.post (url, params, userdata)
+        .done (function (data) {
+            def.resolve(data);
+        })
+        .fail(function () {
+            def.reject();
+        });
+        return def;
+    }
+
+    function metrics (app, action) {
+        require(['io.ox/metrics/main'], function (metrics) {
+            if (!metrics.isEnabled()) return;
+            metrics.trackEvent({
+                app: app,
+                target: 'guard',
+                type: 'click',
+                action: action
+            });
+        });
+    }
+
     return {
         // Send authorization to the oxguard server
-        auth: function authorize(userid, password, extra, keyid)
-            {
-            var def = $.Deferred();
-            var defaultSendAddress = $.trim(settings.get('defaultSendAddress', ''));
-            var userdata = {
-                user_id: userid,
-                ox_password: password,
-                encr_password: '',
-                sessionID: ox.session,
-                lang: ox.language,
-                cid: ox.context_id,
-                email: defaultSendAddress,
-                extrapass: extra ? extra : ''
-            };
-            var url = ox.apiRoot + '/oxguard/login?action=login';
-            var params = '&session=' + ox.session + '&time=' + new Date().getTime();
-            if (keyid !== undefined) params += '&keyid=' + keyid;
-            og_http.post (url, params, userdata)
-            .done (function (data) {
-                def.resolve(data);
-            })
-            .fail(function () {
-                def.reject();
-            });
-            return def;
-        },
+        auth: authorize,
         createKeys: createKeys,
         createKeysWizard: createKeysWizard,
         CreateKeysViewModel: CreateKeysViewModel,
@@ -592,7 +671,14 @@ define('oxguard/oxguard_core', [
         validateEmail: validateEmail,
         handleFailEmail: handleFailEmail,
         getPassword: getpassword,
-        createOxGuardPasswordPrompt: createOxGuardPasswordPrompt
+        showError: showError,
+        sanitize: sanitize,
+        handleErrorHTML: handleErrorHTML,
+        saveAuthToSession: saveAuthToSession,
+        checkAuth: checkAuth,
+        savePassword: savePassword,
+        removeAuth: removeAuth,
+        metrics: metrics
     };
 });
 
