@@ -5,13 +5,14 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/pgp/publickeys', [
     'gettext!oxguard',
     'oxguard/core/og_http',
+    'oxguard/oxguard_core',
     'less!oxguard/style'
-], function (gt, http) {
+], function (gt, http, core) {
 
     var deleting = false;
 
@@ -70,6 +71,19 @@ define('oxguard/pgp/publickeys', [
         $('#og_wait').hide();
     }
 
+    function deleteConfirm (e) {
+        require (['io.ox/core/tk/dialogs'], function (dialogs) {
+            var dialog = new dialogs.ModalDialog({ width: 300, center: true, enter: 'ok' });
+            dialog.header($('<h4>').text(gt('Delete Public Key')));
+            var confirm = $('<span style="padding-left:5px; font-weight:bold;">').append(gt('Click OK to confirm'));
+            dialog.getBody().append(confirm);
+            dialog.addPrimaryButton('ok', gt('OK'), 'ok')
+            .addButton('cancel', gt('Cancel'), 'cancel')
+            .on('ok', function () {
+                deleteShare (e);
+            }).show();
+        });
+    }
     function deleteShare (e) {
         if (deleting) return;
         deleting = true;
@@ -80,6 +94,7 @@ define('oxguard/pgp/publickeys', [
         '&ids=' + encodeURI(trash.parent().attr('value')) +
         '&session=' + ox.session;
         trash.removeClass('fa-trash').addClass('fa-spinner fa-spin');
+        core.metrics('settings', 'delete-public-key');
         $.ajax({
             url: ox.apiRoot + '/oxguard/pgp?action=share' + params,
             type: 'DELETE',
@@ -104,7 +119,7 @@ define('oxguard/pgp/publickeys', [
         var date = new Date();
         var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id +
         '&session=' + ox.session + '&ticks=' + date.getTime();
-        if (list !== undefined )  {
+        if (list !== undefined && list !== 'undefined')  {
             params += '&emails=' + encodeURI(list);
         }
         // Send the request to the oxguard server for the encrypted content key to decrypt
@@ -120,8 +135,9 @@ define('oxguard/pgp/publickeys', [
                 for (var i = 0; i < data.length; i++) {
                     var tr = $('<tr>');
                     if (data[i].guard === true || data[i].shared === true) tr.addClass('oxguard_key_share');
-                    var td1 = $('<td style="text-align:left;max-width:150px;overflow:hidden;text-overflow:ellipsis;">');
-                    td1.append(data[i].email.replace(/>/gi,'&gt;').replace(/</gi,'&lt;'));
+                    var email = data[i].email.replace(/>/gi,'&gt;').replace(/</gi,'&lt;');
+                    var td1 = $('<td class="oxguard_pubkeylist" title="' + email + '">');
+                    td1.append(email);
                     tr.append(td1);
                     var td2 = $('<td>');
                     td2.append(data[i].ids);
@@ -132,7 +148,7 @@ define('oxguard/pgp/publickeys', [
                     var td5 = $('<td class="KeyDelete">');
                     if ((data[i].guard !== true) && (data[i].shared !== true)) {
                         var del = $('<a href="#" value="' + data[i].ids + '" tableid="' + id + '" emaillist="' + list + '"><icon class="fa fa-trash"/></a>')
-                        .click (deleteShare);
+                        .click (deleteConfirm);
                         td5.append(del);
                         showDelete = true;
                     }
@@ -373,7 +389,7 @@ define('oxguard/pgp/publickeys', [
     }
 
     function listPublic (id, list) {
-        if (list === ',,') return;
+        if (list === ',,' || list === '') return;
         var pubdiv = $('<div class="publicKeyDiv"/>');
         var tableHeader = $('<legend>');
         if (id == 'settings') tableHeader = $('<b>');
@@ -394,6 +410,7 @@ define('oxguard/pgp/publickeys', [
             fileinput.on('change', function () {
                 var files = this.files;
                 if (files.length > 0) {
+                    core.metrics('settings', 'upload-public-key');
                     require(['oxguard/pgp/uploadkeys'], function (uploader) {
                         uploader.upload(files, false, '', '', list)
                         .done(function () {
