@@ -4,13 +4,14 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/pgp/reader', [
     'io.ox/core/extensions',
     'oxguard/core/og_http',
+    'oxguard/mail/mail_metrics',
     'gettext!oxguard'
-], function (ext, http, gt) {
+], function (ext, http, metrics, gt) {
     'use strict';
 
     var pgpclass = 'icon-lock fa fa-lock pgp_superscript';
@@ -38,18 +39,39 @@ define('oxguard/pgp/reader', [
         };
         var params = '&folder=' + baton.data.folder_id + '&index=' + index +
             '&userid=' + ox.user_id + '&cid=' + ox.context_id + '&password=' +
-            '&session=' + ox.session + '&emailid=' + baton.data.id + '&auth=' +
+            '&emailid=' + baton.data.id + '&auth=' +
             encodeURIComponent(auth === undefined ? window.oxguarddata.passcode : auth);
 
         decoding(baton);
+        metrics.track('decode-pgp-inline');
         // Send the request to the oxguard server
         http.post(ox.apiRoot, '/oxguard/pgpmail?action=getinline' + params, json)
         .done(function (data) {
-            data = JSON.parse(data);
+            if (typeof data == 'string') data = JSON.parse(data);
+            if (data instanceof Array) data = data[0];
+            // Handle new standardized error response from backend
+            if (data.error !== undefined) {
+                require (['oxguard/oxguard_core'], function (core) {
+                    data.responseText = data.error;
+                    var goFunction = function (id) {
+                        var password = ($('#oxgrpass' + id).val() === undefined) ? '' : $('#oxgrpass' + id).val();
+                        decoding(baton);
+                        require (['oxguard/pgp/reader'], function (reader) {
+                            reader.getInline(baton, password, index, auth);
+                        });
+                    };
+                    core.handleFailEmail (data, baton, deferred, goFunction);
+                });
+                return;
+            }
             var attachments = baton.view.model.get('attachments');
             for (var i = 0; i < attachments.length; i++) {
                 if (attachments[i].disp === 'inline' && attachments[i].content_type.indexOf('text') > -1) {
                     if (attachments[i].content_type.indexOf('html') > -1) {
+                        // Check if was just plaintext wrapped in HTML, in which case, need to convert
+                        if ((data.newcontent.indexOf('<br') < 0) && (data.newcontent.indexOf('<p') < 0)) {
+                            data.newcontent = convertToHTML(data.newcontent);
+                        }
                         attachments[i].content = data.newcontent;
                         baton.data.replytext = data.newcontent;
                         baton.data.replytype = 'text/html';
@@ -87,6 +109,7 @@ define('oxguard/pgp/reader', [
             baton.model = baton.view.model;  // Unlike Guard, we can have main model reflect the changes.
             baton.view.loaded = true;
             baton.view.$el.empty();// Clear out the old template email data
+            delete(baton.view.attachmentView);
             baton.view.redraw();
             window.oxguarddata.current = JSON.parse(JSON.stringify(baton.data));
             baton.view.model.set('Guard', JSON.parse(JSON.stringify(baton.data)));
@@ -164,20 +187,38 @@ define('oxguard/pgp/reader', [
         };
         var params = '&folder=' + baton.data.folder_id +
             '&userid=' + ox.user_id + '&cid=' + ox.context_id +
-            '&session=' + ox.session + '&emailid=' + baton.data.id + '&auth=' +
+            '&emailid=' + baton.data.id + '&auth=' +
             encodeURIComponent(auth === undefined ? window.oxguarddata.passcode : auth);
 
         decoding(baton);
+        metrics.track('decode-pgp-mime');
         // Send the request to the oxguard server
         http.post(ox.apiRoot,'/oxguard/pgpmail?action=getmail' + params, json)
         .done(function (data) {
             try {
-                data = JSON.parse(data);
+                if (typeof data == 'string') data = JSON.parse(data);
+                if (data instanceof Array) data = data[0];
+                // Handle new standardized error response from backend
+                if (data.error !== undefined) {
+                    require (['oxguard/oxguard_core'], function (core) {
+                        var goFunction = function (id) {
+                            var password = ($('#oxgrpass' + id).val() === undefined) ? '' : $('#oxgrpass' + id).val();
+                            decoding(baton);
+                            require (['oxguard/pgp/reader'], function (reader) {
+                                reader.getPGP(baton, password);
+                            });
+                        };
+                        core.handleFailEmail (data, baton, deferred, goFunction);
+                    });
+                    return;
+                }
                 baton.data.attachments = data.attachments;
                 baton.data.PGPresults = data.results;
                 baton.data.content_type = 'multipart/mixed';
                 baton.data.PGPDecoded = true;
                 var attachment = false;
+                var count = 1;
+                var html_found = false;
                 for (var i = 0; i < data.attachments.length; i++) {
                     data.attachments[i].epass = data.results.epassword;
                     data.attachments[i].pgpFormat = 'pgpmime';
@@ -192,10 +233,20 @@ define('oxguard/pgp/reader', [
                             data.attachments[i].content = convertToHTML(data.attachments[i].content);  // Gets displayed in HTML window, so convert lf to <br>, etc
                         }
                         if (data.attachments[i].disp === 'inline') {
-                            baton.data.replytext = data.attachments[i].content;
-                            baton.data.replytype = type;
-                        } else attachment = true;
-                    } else attachment = true;
+                            if (!html_found) {
+                                baton.data.replytext = data.attachments[i].content;
+                                baton.data.replytype = type;
+                                if (type === 'text/html') html_found = true;   // Once we've saved HTML, don't save other reply types
+                            }
+                        } else {
+                            attachment = true;
+                            data.attachments[i].id = count;
+                        }
+                        count++;
+                    } else {
+                        data.attachments[i].id = count++;  // We need to advance the ids for the attachments here.  Multipart sub parts had sim IDs
+                        attachment = true;
+                    }
                     if (data.attachments[i].filename !== undefined) {
                         data.attachments[i].meta = {
                             previewUrl: getMimePreviewUrl(baton.data, data.attachments[i])
@@ -205,8 +256,8 @@ define('oxguard/pgp/reader', [
                 baton.view.model.set('attachment', attachment);
                 baton.view.model.set('attachments', data.attachments);
                 baton.view.model.set('pgpFormat', 'pgpmime');
-                baton.view.model.set('to', data.to);
-                baton.view.model.set('cc', data.cc);
+                baton.view.model.set('to', data.to === undefined ? [] : data.to);
+                baton.view.model.set('cc', data.cc === undefined ? [] : data.cc);
                 baton.view.model.set('PGPDecoded', true);
                 baton.view.model.set('PGP', true);
                 baton.view.model.set('PGPresults', data.results);
@@ -216,6 +267,7 @@ define('oxguard/pgp/reader', [
                 baton.view.expand();
                 baton.view.loaded = true;
                 baton.view.$el.empty();// Clear out the old template email data
+                delete(baton.view.attachmentView);
                 baton.view.redraw();
                 window.oxguarddata.current = JSON.parse(JSON.stringify(baton.data));
                 baton.view.model.set('Guard', JSON.parse(JSON.stringify(baton.data)));
@@ -273,17 +325,21 @@ define('oxguard/pgp/reader', [
     }
     // Find cid links in body of email and replace with Guard links
     function replace_content_id (content, epass, data) {
-        content = content.replace(/cid:[^@]+@GUARD/, function (c) {
+        content = content.replace(/src[\ ]*=[\ ]*"cid:[^"]+/g, function (c) {
+            var id = c;
+            if (c.indexOf(':') > 0) {
+                id = c.substring(c.indexOf(':') + 1).trim();
+            }
             var params = '&emailid=' + data.id +
-            '&session=' + ox.session +
             '&auth=' + encodeURIComponent(window.oxguarddata.passcode) +
             '&userid=' + ox.user_id +
             '&cid=' + ox.context_id +
             '&epassword=' + encodeURIComponent(epass) +
             '&folder=' + data.folder_id +
-            '&content_id=' + encodeURIComponent(c.substring(4));
+            '&content_id=' + encodeURIComponent(id) +
+            '&session=' + ox.session;
             var link = location.protocol + '//' + location.host + ox.apiRoot + '/oxguard/pgpmail/inline?action=getattachcid' + params;
-            return (link);
+            return ('src="' + link);
         });
         return (content);
     }
@@ -295,25 +351,24 @@ define('oxguard/pgp/reader', [
         var signedicon = null;
         if (data.verified !== undefined) {
             if (data.verified) {
-                var signedicon = $('<i class="oxguard_icon_fa fa-pencil-square-o fa" aria-hidden="true" title="' + gt('This Email was signed and verified') + '"/>');
+                var signedicon = $('<i class="oxguard_icon_fa fa-pencil-square-o fa guard_signed" aria-hidden="true" title="' + gt('This Email was signed and verified.') + '"/>');
                 flagpicker.after(signedicon);
             } else {
                 if (data.signature && !data.verified) {
                     if (data.missingPublicKey) {
-                        signedicon = $('<i class="oxguard_icon_fa fa-pencil-square-o fa guard_signed" style="color:lightgrey" aria-hidden="true" title="' + gt('This Email was signed but unable to verify') + '"/>');
+                        signedicon = $('<i class="oxguard_icon_fa fa-pencil-square-o fa guard_signed" style="color:lightgrey" aria-hidden="true" title="' + gt('This Email was signed but unable to verify.') + '"/>');
                     } else
-                        signedicon = $('<i class="oxguard_icon_fa_alert fa-pencil-square fa" aria-hidden="true" title="' + gt('This Email was signed and failed verification') + '"/>');
+                        signedicon = $('<i class="oxguard_icon_fa_alert fa-pencil-square fa guard_signed" aria-hidden="true" title="' + gt('This Email was signed and failed verification.') + '"/>');
                     flagpicker.after(signedicon);
                 }
             }
         }
         var pgp = $('<div class="oxguard_icon_fa" title="' + gt('This Email was encrypted with PGP.') + '"/>');
         if (_.device('small')) {  // Formatting for mobile
-            pgp.css('margin-right', '20px');
-            if (signedicon !== null) signedicon.css('margin-top', '-3px');
+            pgp.css('margin-right', '29px');
+            if (signedicon !== null) signedicon.css('margin-top', '-1px');
         } else {
-            pgp.css('margin-right', '-9px').css('padding-top', '3px');
-            if (signedicon !== null) signedicon.css('margin-top', '1px');
+            pgp.css('margin-right', '-15px');
         }
 
         pgp.append('P<span style="font-size:0.5em;">gp</span>');
