@@ -4,41 +4,49 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/pgp/register', [
     'io.ox/core/extensions',
     'io.ox/core/extPatterns/links',
+    'io.ox/core/extPatterns/actions',
     'oxguard/core/og_http',
     'oxguard/pgp/checker',
     'io.ox/core/api/account',
+    'io.ox/core/capabilities',
     'pgp_mail/util',
+    'oxguard/mail/mail_metrics',
     'settings!oxguard',
     'gettext!oxguard'
-], function (ext, links, http, checker, account, util, settings, gt) {
+], function (ext, links, actions, http, checker, account, capabilities, util, metrics, settings, gt) {
     'use strict';
 
     var popupBlockCount = 0;
 
     // Detail View Extensions
-    ext.point('io.ox/mail/detail').extend({
-        index: 2,
+    ext.point('io.ox/mail/detail/body').extend({
         id: 'ogPGPCheck',
         draw: function (baton) {
-            checker.checkPGP.call(this, baton);
-            baton.view.listenTo(baton.view.model, 'change:attachments', function () {
-                checker.checkPGP(baton);
-            });
+            if (this[0] !== undefined) {
+                var location;
+                if (this[0].host !== undefined) {  // Chrome
+                    location = $(this[0].host);
+                } else { // Others
+                    location = $(this[0].firstChild);
+                }
+                checker.checkPGP(baton, location);
+            }
         }
     });
 
-    ext.point('io.ox/mail/mobile/detail/header').extend({
+    ext.point('io.ox/mail/mobile/detail/body').extend({
         index: 230,
         id: 'ogPGPCheckMobile',
         draw: function (baton) {
-            checker.checkPGP.call(this, baton);
+            var location = this[0];
+            checker.checkPGP.call(this, baton, location);
             baton.view.listenTo(baton.view.model, 'change:attachments', function () {
-                checker.checkPGP(baton);
+                checker.checkPGP(baton, location);
                 if (baton.view.$el === null) return;
                 if (!_.device('ios')) {
                     window.setTimeout(function () {
@@ -62,13 +70,14 @@ define('oxguard/pgp/register', [
                     '<i class ="icon-star-half-empty" style="color:black; margin-top:5px;"/></span>';
                 lockdiv.append($(lockstack));
                 if (baton.data.PGPresults.verified === true) {
-                    lockdiv.append('<i class="icon-edit" title="' + gt('This Email was signed by the sender and verified') + '"/>');
+                    lockdiv.append('<i class="icon-edit" title="' + gt('This Email was signed by the sender and verified.') + '"/>');
                 }
                 $(this).prepend(lockdiv);
             }
         }
     });
 
+    // Methods for actions
     // Check if attachment filename ends with .asc
     function isASC (e) {
         try {
@@ -97,15 +106,13 @@ define('oxguard/pgp/register', [
                 for (var i = 0; i < e.context.length; i++) {
                     if (e.context[i].pgpFormat === 'pgpinline') return (true);
                     if (e.context[i].pgpFormat === 'pgpmime') return (false);
-                    if (e.context[i].filename.indexOf('.pgp') > 0) return true;
+                    //if (e.context[i].filename.indexOf('.pgp') > 0) return true;
                 }
             } else {
                 if (e.context.pgpFormat === 'pgpinline') return (true);
                 if (e.context.pgpFormat === 'pgpmime') return (false);
             }
-            var filename = e.context.filename;
-            if (filename === undefined) return false;
-            return (filename.indexOf('.pgp') > 0);
+            return false;
         } catch (d) {
             console.log(d);
             return false;
@@ -115,19 +122,20 @@ define('oxguard/pgp/register', [
     // Email Actions
 
     // Make excisting mail extensions Guard aware
-    addGuardAwareExtension ('io.ox/mail/actions/download-attachment');
-    addGuardAwareExtension ('io.ox/mail/actions/open-attachment');
-    addGuardAwareExtension ('io.ox/mail/actions/preview-attachment');
-    addGuardAwareExtension ('io.ox/mail/actions/slideshow-attachment');
-    addGuardAwareExtension ('io.ox/mail/actions/save-attachment');
-    addGuardAwareExtension ('io.ox/mail/actions/vcard');
-    addGuardAwareExtension ('io.ox/mail/actions/ical');
-    addGuardAwareExtension ('io.ox/mail/office/text/edit-as-new');
-    addGuardAwareExtension ('io.ox/mail/office/spreadsheet/edit-as-new');
-    addGuardAwareExtension ('io.ox/mail/actions/view-attachment');
+    addGuardAwareAttachmentExtension ('io.ox/mail/actions/download-attachment');
+    addGuardAwareAttachmentExtension ('io.ox/mail/actions/open-attachment');
+    addGuardAwareAttachmentExtension ('io.ox/mail/actions/preview-attachment');
+    addGuardAwareAttachmentExtension ('io.ox/mail/actions/slideshow-attachment');
+    addGuardAwareAttachmentExtension ('io.ox/mail/actions/save-attachment');
+    addGuardAwareAttachmentExtension ('io.ox/mail/actions/vcard');
+    addGuardAwareAttachmentExtension ('io.ox/mail/actions/ical');
+    addGuardAwareAttachmentExtension ('io.ox/mail/office/text-edit-asnew');
+    addGuardAwareAttachmentExtension ('io.ox/mail/office/spreadsheet-edit-asnew');
+    addGuardAwareAttachmentExtensionWithSig ('io.ox/mail/actions/view-attachment');
+    addGuardAware('io.ox/mail/actions/inplace-reply');
 
     // Adds check for Guard files to base and office UI extensions
-    function addGuardAwareExtension (e) {
+    function addGuardAwareAttachmentExtension (e) {
         new links.Action(e, {
             id: 'stop',
             index: 1,
@@ -140,14 +148,72 @@ define('oxguard/pgp/register', [
         });
     }
 
+    // Adds check for Guard files to base and office UI extensions
+    function addGuardAwareAttachmentExtensionWithSig (e) {
+        new links.Action(e, {
+            id: 'stop',
+            index: 1,
+            requires: function (e) {
+                if (isPGPAttach(e) || isPGPSignature(e)) {
+                    e.stopPropagation();
+                }
+                return false;
+            }
+        });
+    }
+
+    // Adds check for PGP email, and if true, stops the extension
+    function addGuardAware (e) {
+        new links.Action(e, {
+            id: 'stop',
+            index: 1,
+            requires: function (e) {
+                if (e.context instanceof Array) {
+                    for (var i = 0; i < e.context.length; i++) {
+                        if (e.context[i].PGP === true) e.stopPropagation();
+                    }
+                    return;
+                }
+                if (e.context.PGP === true) e.stopPropagation();
+                return;
+            }
+        });
+    }
+
+    //  Make the view attachment aware of Guard attachments
+    ext.point('io.ox/mail/actions/view-attachment').extend({
+        index: 1,
+        id: 'repl',
+        multiple: function (e, baton) {
+            if (isPGPAttachList(e)) {
+                actions.invoke('io.ox/mail/actions/view-OGPGPattachment', null, baton);
+                baton.stopPropagation();
+            }
+        }
+    });
+
+    function isPGPAttachList(e) {
+        try {
+            for (var i = 0; i < e.length; i++) {
+                if (e[i].pgpFormat !== undefined) return true;
+            }
+        } catch (e) {
+            console.log(e);
+        }
+        return false;
+    }
+
     // Action to open OxGuard attachment
     new links.Action('io.ox/mail/actions/view-OGPGPattachment', {
         id: 'viewOGPGP',
         requires: function (e) {
+            // Do not open viewer for signature
+            if (isPGPSignature(e)) return false;
             return !isInline(e) && isPGPAttach(e);
         },
-        multiple: function (list) {
-            _(list).each(function (data) {
+        multiple: function (list, baton) {
+            var i = 0;
+            _(list).each(function (data, j) {
                 var params = '&emailid=' + data.parent.id +
                 '&attach=' + data.id +
                 '&session=' + ox.session +
@@ -162,9 +228,13 @@ define('oxguard/pgp/register', [
                 data.origData = data;
                 data.folder_id = data.parent.folder_id;
                 delete(data.mail);
+                if (baton.startItem) {
+                    if (data.id === baton.startItem.id) i = j;
+                }
             });
+            metrics.track('view-pgp-mime-attachment');
             ox.load(['io.ox/mail/actions/viewer']).done(function (action) {
-                action({ files: list });
+                action({ files: [ list[i] ], selection: list[i] });  // Temp fix for current UI bug.  Change to just list once fixed
             });
         }
     });
@@ -193,6 +263,7 @@ define('oxguard/pgp/register', [
                 data.origData = data;
                 delete(data.mail);
             });
+            metrics.track('view-pgp-inline-attachment');
             ox.load(['io.ox/mail/actions/viewer']).done(function (action) {
                 action({ files: list });
             });
@@ -218,12 +289,13 @@ define('oxguard/pgp/register', [
                 '&attname=' + encodeURIComponent(data.filename);
                 var link = ox.apiRoot + '/oxguard/pgpmail/' + encodeURIComponent(data.filename) + '?action=getattach' + params;
                 var popup = window.open(link);
+                metrics.track('open-pgp-attachment');
                 if (popup === null || popup === undefined) {
                     // If popup blocked, give one try to see if user notices, otherwise alert message regarding blocking
                     if (popupBlockCount === 1) {
                         require (['io.ox/core/notifications'], function (notifications) {
-                            //#. Error message when trying to open a file with popup blocker on browser blocking
-                            notifications.yell('error', gt('Your pop-up blocker may have prevented a Guard window that provides application functionality.'));
+                            //#. Error message when trying to open a file with popup blocker on browser blocking, %s product name
+                            notifications.yell('error', gt('Your pop-up blocker may have prevented a %s window that provides application functionality.', window.oxguarddata.productName));
                         });
                         //  window.location.href = link;
                     }
@@ -240,6 +312,7 @@ define('oxguard/pgp/register', [
             return !isInline(e) && isPGPAttach(e);
         },
         multiple: function (list) {
+            metrics.track('download-pgp-mime-attachment');
             _(list).each(function (data) {
                 downloadMime(data);
             });
@@ -289,6 +362,7 @@ define('oxguard/pgp/register', [
         '&cc=' + data.cc +
         '&download=true' +
         '&attname=' + encodeURIComponent(filename);
+        metrics.track('download-pgp-inline-attachment');
         var link = ox.apiRoot + '/oxguard/pgpmail/' + encodeURIComponent(filename) + '?action=getinlineattach' + params;
         $('#tmp').append(
                 $('<iframe>', { src: link, 'class': 'hidden download-frame', id: 'download' + data.id })
@@ -304,6 +378,7 @@ define('oxguard/pgp/register', [
             return (e.baton.data.pgpFormat !== undefined);
         },
         multiple: function (list) {
+            metrics.track('save-decoded-pgp-attachment-to-drive');
             require(['oxguard/pgp/saveattach'], function (action) {
                 action.multiple(list, true);
             });
@@ -311,14 +386,16 @@ define('oxguard/pgp/register', [
     });
     // Save encrypted PGP attachment to drive
     new links.Action('io.ox/mail/actions/save-OGPGPEncrypted', {
-        id: 'SaveDecodedPGPAttachment',
+        id: 'SaveEncryptedPGPAttachment',
         requires: function (e) {
+            if (!capabilities.has('guard-drive') && !capabilities.has('guard:drive')) return (false);
             if (e.baton.data instanceof Array) {
                 return (e.baton.data[0].pgpFormat !== undefined);
             }
             return (e.baton.data.pgpFormat !== undefined);
         },
         multiple: function (list) {
+            metrics.track('save-encrypted-pgp-attachment-to-drive');
             if (list[0].pgpFormat === 'pgpinline') {
                 require(['io.ox/mail/actions/attachmentSave'], function (action) {
                     action.multiple(list);
@@ -350,12 +427,13 @@ define('oxguard/pgp/register', [
                     '&attname=' + encodeURIComponent(filename);
                 var link = ox.apiRoot + '/oxguard/pgpmail/' + encodeURIComponent(filename) + '?action=getinlineattach' + params;
                 var popup = window.open(link);
+                metrics.track('open-pgp-inline-attachment');
                 if (popup === null || popup === undefined) {
                     // If popup blocked, give one try to see if user notices, otherwise alert message regarding blocking
                     if (popupBlockCount === 1) {
                         require (['io.ox/core/notifications'], function (notifications) {
-                            //#. Error message when trying to open a file with popup blocker on browser blocking
-                            notifications.yell('error', gt('Your pop-up blocker may have prevented a Guard window that provides application functionality.'));
+                            //#. Error message when trying to open a file with popup blocker on browser blocking, %s product name
+                            notifications.yell('error', gt('Your pop-up blocker may have prevented a %s window that provides application functionality.', window.oxguarddata.productName));
                         });
                         //  window.location.href = link;
                     }
@@ -386,9 +464,11 @@ define('oxguard/pgp/register', [
                     type = e.context.content_type;
                     name = e.context.filename;
                 }
-                if (type === 'application/pgp-keys') return true;
-                if (name === 'public.asc') return true;
-                return (/[0-9A-F]{8}\.asc/).test(name); // Regex for 8 hex.asc
+                if (type !== undefined) {
+                    if (type.indexOf('application/pgp-keys') > -1) return true;
+                }
+                if (name === 'public.asc' || name === 'publickey.asc') return true;
+                return (/[0x]*[0-9A-F]{8}\.asc/i).test(name); // Regex for 8 hex.asc
             }
         }
         return false ;
@@ -420,6 +500,7 @@ define('oxguard/pgp/register', [
             return isKey(e);
         },
         multiple: function (list) {
+            metrics.track('import-pgp-public-key');
             doImportKey (list);
         }
     });
@@ -432,6 +513,7 @@ define('oxguard/pgp/register', [
         if (window.oxguarddata.passcode === 'No Key') {
             require(['oxguard/oxguard_core'], function (core) {
                 //FIXME: is this needed? Why?
+                metrics.track('create-keys-to-import-public');
                 core.createKeysWizard()
                 .done(function () {
                     loadPublicKey(list);
@@ -456,6 +538,7 @@ define('oxguard/pgp/register', [
             return false;
         },
         multiple: function (list) {
+            metrics.track('import-encrypted-vCard');
             require (['settings!io.ox/core', 'io.ox/core/notifications'], function (coreConfig, notify) {
                 _(list).each(function (data) {
                     var contact_folder = coreConfig.get('folder/contacts');
@@ -472,9 +555,15 @@ define('oxguard/pgp/register', [
                     var link = ox.apiRoot + '/oxguard/pgpmail/?action=importvcard' + params;
                     http.get(link, params)
                     .done(function (d) {
-                        if (d.trim() === 'Warn') {
-                            notify.yell('success', gt('VCard imported with warnings'));
-                        } else notify.yell('success', gt('VCard imported'));
+                        if (d.error !== undefined) {
+                            if (d.categories === 'WARNING') {
+                                notify.yell('warning', gt('VCard imported with warnings') + '\r\n' + d.error);
+                                return;
+                            }
+                        } else {
+                            notify.yell('error', gt('Failed to import vcard') + '\r\n' + d.error);
+                        }
+                        notify.yell('success', gt('VCard imported'));
                     })
                     .fail(function () {
                         notify.yell('error', gt('Failed to import vcard'));
@@ -484,13 +573,26 @@ define('oxguard/pgp/register', [
         }
     });
 
+    function isPGPSignature (e) {
+        if (e.context instanceof Array) {
+            for (var i = 0; i < e.context.length; i++) {
+                if (e.context[i].content_type === 'application/pgp-signature') return true;
+            }
+            return false;
+        }
+        if (e.context.content_type === 'application/pgp-signature') return true;
+        return false;
+    }
+
     // Return true if of type PGP
     //FIXME: move to util module
     function isPGPAttach(e) {
         if (e.context instanceof Array) {
             for (var i = 0; i < e.context.length; i++) {
                 if (e.context[i].pgpFormat !== undefined) return true;
-                if (e.context[i].content_type === 'application/pgp-encrypted') return true;
+                if (e.context[i].content_type === 'application/pgp-encrypted') {
+                    return true;
+                }
             }
             return false;
         }
@@ -515,6 +617,7 @@ define('oxguard/pgp/register', [
             return e.collection.has('some') && (e.collection.has('read') || !e.collection.has('toplevel'));
         },
         multiple: function (list) {
+            metrics.track('print-pgp-email');
             require (['io.ox/core/print'], function (print) {
                 var nonPGP = [];
                 var isPGP = [];
@@ -537,12 +640,13 @@ define('oxguard/pgp/register', [
 
     // Link within viewer to download an inline attachment
     new links.Action('io.ox/mail/actions/downloadInlineView', {
-        id: 'viewertest',
+        id: 'viewerdownloadInline',
         requires: function (e) {
             if (e.baton.model.get('pgpFormat') === 'pgpinline') return (true);
             return (false);
         },
         action: function (e) {
+            metrics.track('download-pgp-inline-attachment-viewer');
             e.data.mail = e.data.parent;
             downloadInline(e.data);
         }
@@ -555,6 +659,7 @@ define('oxguard/pgp/register', [
             return (false);
         },
         action: function (e) {
+            metrics.track('download-pgp-mime-attachment-viewer');
             e.data.mail = e.data.parent;
             downloadMime(e.data);
         }
