@@ -48,7 +48,16 @@ define('oxguard/pgp/saveattach',[
                             type: 'PUT',
                             url: ox.apiRoot + '/oxguard/pgp?action=savedecodedattachment&session=' + ox.session,
                             data: JSON.stringify(params),
-                            success: function () {
+                            contentType:'application/json; charset=utf-8',
+                            success: function (data) {
+                                try {
+                                    data = _.isArray(data) ? data[0] : data;
+                                    if (data.error !== undefined) {
+                                        def.reject(data.error);
+                                    }
+                                } catch (e) {
+                                    console.log(e);
+                                }
                                 def.resolve('success');
                             }
                         })
