@@ -4,23 +4,26 @@ define('oxguard/pgp/settings/pane', [
     'oxguard/pgp/publickeys',
     'oxguard/core/og_http',
     'oxguard/util',
+    'oxguard/passwords',
+    'oxguard/oxguard_core',
     'settings!oxguard',
     'io.ox/backbone/mini-views/help',
     'gettext!oxguard'
-], function (ext, dialogs, pubkeys, http, util, settings, HelpView, gt) {
+], function (ext, dialogs, pubkeys, http, util, passwords, core, settings, HelpView, gt) {
     'use strict';
 
     var userKeyData = null;
+    var thisNode = null;
 
     function downloadPublic() {
         var pgpHeader = $('<div style="padding-bottom:20px;">');
-        var downloadbutton = $('<button type="button" class="btn btn-primary">' + gt('Download PGP Public Key') + '</button>');
+        var downloadbutton = $('<button type="button" class="btn btn-primary" style="margin-right:20px;">' + gt('Download PGP Public Key') + '</button>');
         downloadbutton.on('click', function () {
-            var params = '&id=' + ox.user_id + '&cid=' + ox.context_id;
+            var params = '&id=' + ox.user_id + '&cid=' + ox.context_id + '&session=' + ox.session;
             window.open(ox.apiRoot + '/oxguard/pgpmail/public.asc?action=getkeybyid' + params, '_blank');
         });
 
-        var sendButton = $('<button type="button" class="btn btn-primary" style="margin-left:20px;">' + gt('Email your PGP Public Key') + '</button>')
+        var sendButton = $('<button type="button" class="btn btn-primary">' + gt('Email your PGP Public Key') + '</button>')
          .on('click', sendPublic);
         pgpHeader.append(downloadbutton).append(sendButton);
         return (pgpHeader);
@@ -29,6 +32,7 @@ define('oxguard/pgp/settings/pane', [
     ///// Local Key Management
 
     function keys() {
+        if (!settings.get('advanced')) return;
         var header = $('<legend class="sectiontitle" style="margin-bottom:5px;">').append(gt('Your Keys'));
         header.append(new HelpView({
             base: 'help-guard',
@@ -77,9 +81,7 @@ define('oxguard/pgp/settings/pane', [
 
     function updateUserKeyTable() {
         var deferred = $.Deferred();
-        var date = new Date();
-        var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id +
-        '&session=' + ox.session + '&ticks=' + date.getTime();
+        var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id;
         // Send the request to the oxguard server for the encrypted content key to decrypt
         http.get(ox.apiRoot + '/oxguard/pgp?action=getuserkeys', params)
         .done(function (grpdata) {
@@ -177,7 +179,7 @@ define('oxguard/pgp/settings/pane', [
             var dialog = new dialogs.CreateDialog({ width: 450, center: true,  enter: 'ok' });
             dialog.header($('<h4>').text(gt('Adding Keys')));
 
-            var uploadheader = $('<p>' + gt('If you already have a private key, you can upload it here') + '</p>');
+            var uploadheader = $('<p>' + gt('If you already have a private key, you can upload it here.') + '</p>');
             var uploadbutton = $('<button type="button" class="btn btn-primary">' + gt('Upload Private Key') + '</button>');
             uploadbutton.on('click', function () {
                 fileinput.click();
@@ -207,7 +209,7 @@ define('oxguard/pgp/settings/pane', [
                 fileinput = $('<input type="file" name="localPrivateKey" style="display:none;">');
                 $('#guardFiles').append(fileinput);
             }
-            var createNewHeader = $('<br><p>' + gt('Finally, you can have a new PGP Key Pair created for your account') + '</p>');
+            var createNewHeader = $('<br><p>' + gt('Finally, you can have a new PGP Key Pair created for your account.') + '</p>');
             var createButton = $('<button type="button" class="btn btn-primary">' + gt('Create New Keys') + '</button>')
             .click(function () {
                 createNew();
@@ -224,7 +226,7 @@ define('oxguard/pgp/settings/pane', [
         require (['io.ox/core/tk/dialogs'], function (dialogs) {
             var dialog = new dialogs.CreateDialog({ width: 450, center: true,  enter: 'ok' });
             dialog.header($('<h4>').text(gt('Adding UserID')));
-            var instr = $('<p>' + gt('Add a name and email address to this public key') + '</p>');
+            var instr = $('<p>' + gt('Add a name and email address to this public key.') + '</p>');
             var table = $('<table class="oxguard_settings">');
             var tr1 = $('<tr>');
             var td1 = $('<td>' + gt('Name') + '</td>');
@@ -236,9 +238,10 @@ define('oxguard/pgp/settings/pane', [
             tr2.append(td2).append($('<td>').append(email));
             table.append(tr1).append(tr2);
             var instr2 = $('<span style="margin-top:5px; display:block;">' + gt('Please enter your key password') + '</span></br>');
-            var pass = $('<input type="password" name="uidPassword"/>');
+            var pass = passwords.createPasswordInput('uidPassword');
+            var noSaveWorkAround = $('<input style="display:none" type="text" name="dontremember"/><input style="display:none" type="password" name="dontrememberpass"/>');
             var errortext = $('<br><span style="color:rgb(237, 81, 81); padding:15px; display:none; float:right;" name="uidError"></span>');
-            dialog.getBody().append(instr).append(table).append(instr2).append(pass).append(errortext);
+            dialog.getBody().append(instr).append(table).append(instr2).append(noSaveWorkAround).append(pass).append(errortext);
             dialog
             .addPrimaryButton('ok', gt('OK'), 'ok')
             .addButton('cancel', gt('Cancel'), 'cancel')
@@ -246,7 +249,7 @@ define('oxguard/pgp/settings/pane', [
                 var email = $('[name="uidEmail"]').val();
                 var name = $('[name="uidName"]').val();
                 var password = $('[name="uidPassword"]').val();
-                require(['oxguard/oxguard_core', 'io.ox/core/notifications'], function (core, notify) {
+                require(['io.ox/core/notifications'], function (notify) {
                     if (!core.validateEmail(email)) {
                         editUID(id, gt('Invalid Email Address'));
                         return;
@@ -263,7 +266,8 @@ define('oxguard/pgp/settings/pane', [
                         email: email,
                         name: name
                     };
-                    var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id + '&keyid=' + id + '&session=' + ox.session;
+                    core.metrics('settings', 'edit-pgp-uid');
+                    var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id + '&keyid=' + id;
                     http.post(ox.apiRoot + '/oxguard/pgp?action=adduserid', params, data)
                     .done (function () {
                         notify.yell('success', gt('User ID added'));
@@ -330,8 +334,9 @@ define('oxguard/pgp/settings/pane', [
             dialog.header($('<h4>').text(gt('Delete Private Key')));
             var body = $('<p>' + gt('You will no longer be able to decode any items that were encrypted with this key!') + '</p>');
             var body2 = $('<p>' + gt('Enter your password below to confirm and verify') + '</p>');
-            var password = $('<input type="password" id="deletepass" />');
-            dialog.getBody().append(body).append(body2).append(password);
+            var password = passwords.createPasswordInput('deletepass');
+            var noSaveWorkAround = $('<input style="display:none" type="text" name="dontremember"/><input style="display:none" type="password" name="dontrememberpass"/>');
+            dialog.getBody().append(body).append(body2).append(noSaveWorkAround).append(password);
             dialog.addPrimaryButton('delete', gt('Delete'), 'delete')
             .addButton('cancel', gt('Cancel'), 'cancel')
             .on('delete', function () {
@@ -350,7 +355,8 @@ define('oxguard/pgp/settings/pane', [
                                 userid: ox.user_id,
                                 cid: ox.context_id
                             };
-                            var params = '&session=' + ox.session;
+                            var params = '';
+                            core.metrics('settings', 'delete-private-key');
                             http.post(ox.apiRoot + '/oxguard/pgp?action=deleteprivkey', params, json)
                             .done (function () {
                                 updateUserKeys();
@@ -402,13 +408,14 @@ define('oxguard/pgp/settings/pane', [
     }
 
     function deletePublic (keyid) {
-        var params = '&session=' + ox.session;
+        var params = '';
         require (['io.ox/core/notifications'], function (notify) {
             var json = {
                 userid: ox.user_id,
                 cid: ox.context_id,
                 keyid: keyid
             };
+            core.metrics('settings', 'delete-public-key');
             http.post(ox.apiRoot + '/oxguard/pgp?action=deletelocalpublic', params, json)
             .done (function () {
                 updateUserKeys();
@@ -426,7 +433,8 @@ define('oxguard/pgp/settings/pane', [
             dialog.header($('<h4>').text(gt('Revoke Private Key')));
             var body = $('<p>').text(gt('This will advise people not to use this key.  You can still use the key to decode existing items.'));
             var body2 = $('<p>').text(gt('Enter your password below to confirm and verify'));
-            var password = $('<input type="password" id="revokepass" />');
+            var password = passwords.createPasswordInput('revokepass');
+            var noSaveWorkAround = $('<input style="display:none" type="text" name="dontremember"/><input style="display:none" type="password" name="dontrememberpass"/>');
             var reasonhead = $('<br style="line-height:2em;">' + gt('Reason') + '<br style="line-height:2em;">');
             var reason = $('<select id="revokereason" style="padding:3px;">')
                 .append('<option value="NO_REASON">' + gt('No Reason') + '</option>')
@@ -435,7 +443,7 @@ define('oxguard/pgp/settings/pane', [
                 .append('<option value="KEY_RETIRED">' + gt('Key retired') + '</option>')
                 .append('<option value="USER_NO_LONGER_VALID">' + gt('User no longer valid') + '</option>');
 
-            dialog.getBody().append(body).append(body2).append(password).append(reasonhead).append(reason);
+            dialog.getBody().append(body).append(body2).append(noSaveWorkAround).append(password).append(reasonhead).append(reason);
             dialog.addPrimaryButton('revoke', gt('Revoke'), 'revoke')
             .addButton('cancel', gt('Cancel'), 'cancel')
             .on('revoke', function () {
@@ -456,7 +464,8 @@ define('oxguard/pgp/settings/pane', [
                                 cid: ox.context_id,
                                 reason: reason
                             };
-                            var params = '&session=' + ox.session;
+                            var params = '';
+                            core.metrics('settings', 'revoke-private-key');
                             http.post(ox.apiRoot + '/oxguard/pgp?action=revokeprivkey', params, json)
                             .done (function () {
                                 updateUserKeys();
@@ -497,13 +506,22 @@ define('oxguard/pgp/settings/pane', [
                 var instructions2 = $('<p>').append(gt('Do not distribute this key.  It is for your use only'));
                 var downloadprivbutton = $('<button type="button" class="btn btn-primary" style="margin-bottom:17px; margin-top:8px;">' + gt('Download PGP Private Key') + '</button>');
                 downloadprivbutton.click(function () {
-                    downloadPrivate(data.GuardKey);
+                    downloadPrivate(data.GuardKey, false);
                     dialog.close();
                 });
-                dialog.getBody().append(instructions).append(instructions2).append(downloadprivbutton).append('<br>');
+                var downloadbothbutton = $('<button type="button" class="btn btn-primary" style="margin-bottom:17px; margin-top:8px;">' + gt('Download Public and Private Key') + '</button>');
+                downloadbothbutton.click(function () {
+                    downloadPrivate(data.GuardKey, true);
+                    dialog.close();
+                });
+                dialog.getBody().append(instructions).append(instructions2)
+                .append(downloadprivbutton)
+                .append(downloadbothbutton)
+                .append('<br>');
             }
             var downloadbutton = $('<button type="button" class="btn btn-primary">').text(gt('Download PGP Public Key'));
             downloadbutton.on('click', function () {
+                core.metrics('settings', 'download-public-key');
                 var params = '&id=' + ox.user_id + '&cid=' + ox.context_id + '&keyid=' + data.GuardKey;
                 window.open(ox.apiRoot + '/oxguard/pgpmail/public.asc?action=getkeybyid' + params, '_blank');
                 dialog.close();
@@ -565,8 +583,9 @@ define('oxguard/pgp/settings/pane', [
 
         wait();
         var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id +
-        '&session=' + ox.session + '&keyid=' + id;
+        '&keyid=' + id;
         // Send the request to the oxguard server for the encrypted content key to decrypt
+        core.metrics('settings', 'change-current-key');
         http.get(ox.apiRoot + '/oxguard/pgp?action=makecurrent', params)
         .done(function () {
             updateUserKeyTable ();
@@ -583,22 +602,28 @@ define('oxguard/pgp/settings/pane', [
 
     function createNew () {
         require (['oxguard/oxguard_core', 'io.ox/core/notifications'], function (core, notify) {
+            core.metrics('settings', 'create-keys-new');
             core.createKeys()
             .done(function () {
                 updateUserKeyTable();
             })
             .fail(function (e) {
-                if (e === 'cancel') return;
+                if (userKeyData.length === 0) {  // If cancelled and no keys, then reset passcode
+                    window.oxguarddata.passcode = 'No Key';
+                }
+                if (e === 'cancel') {
+                    return;
+                }
                 notify.yell('error', e.responseText);
             });
         });
     }
 
-    function downloadPrivate (id) {
+    function downloadPrivate (id, both) {
         require (['oxguard/oxguard_core', 'io.ox/core/notifications'], function (core, notify) {
             core.getPassword()
             .done (function (e) {
-                core.auth(ox.user_id, e, null, id)
+                core.auth(ox.user_id, e.password, null, id)
                 .done (function (authdata) {
                     if (authdata.auth === 'Bad Password') {
                         notify.yell('error', gt('Bad password'));
@@ -608,7 +633,11 @@ define('oxguard/pgp/settings/pane', [
                     }
                     if (authdata.auth.length > 20) {
                         /// get the key
-                        var params = '&id=' + ox.user_id + '&cid=' + ox.context_id + '&keyid=' + id + '&auth=' + encodeURIComponent(authdata.auth);
+                        core.metrics('settings', 'download-private');
+                        var params = '&id=' + ox.user_id + '&cid=' + ox.context_id + '&keyid=' + id +
+                        '&auth=' + encodeURIComponent(authdata.auth) +
+                        '&both=' + (both ? 'true' : 'false') +
+                        '&session=' + ox.session;
                         var link = ox.apiRoot + '/oxguard/pgp/private.asc?action=getprivkeybyid' + params;
                         $('#tmp').append(
                                 $('<iframe>', { src: link, 'class': 'hidden download-frame', id: 'priv' })
@@ -627,7 +656,7 @@ define('oxguard/pgp/settings/pane', [
 
     function checkTempPassword (auth) {
         if (auth.indexOf('Password Needed') > -1) {
-            require (['oxguard/oxguard_core'], function (core) {
+            require (['oxguard/pgp/checker'], function (core) {
                 core.createOxGuardPasswordPrompt();
             });
         }
@@ -636,7 +665,8 @@ define('oxguard/pgp/settings/pane', [
     // Upload users public key without private
     function uploadLocalPublic (dialog) {
         var uploadHeader = $('<div style="padding-top:10px;"/>')
-        .append('<p>' + gt('If you would like to upload a public key only, then do so here.  This will allow you to encrypt files and receive encrypted emails using Guard, but you will need to use the private key with another program to decode the items.') + '</p>');
+        //#. %s product name
+        .append('<p>' + gt('If you would like to upload a public key only, then do so here.  This will allow you to encrypt files and receive encrypted emails using %s, but you will need to use the private key with another program to decode the items.', window.oxguarddata.productName) + '</p>');
         var fileinput;
         var findfile = $('#guardFiles').find('[name="localPublicKey"]');
         if (findfile.length > 0) {
@@ -652,6 +682,7 @@ define('oxguard/pgp/settings/pane', [
             fileinput.on('change', function () {
                 var files = this.files;
                 if (files.length > 0) {
+                    core.metrics('settings', 'upload-public-key-only');
                     require(['oxguard/pgp/uploadkeys'], function (uploader) {
                         uploader.upload(files, true)
                         .done(function () {
@@ -699,6 +730,7 @@ define('oxguard/pgp/settings/pane', [
                     raw: true
                 };
                 var attachments = [body, attach];
+                core.metrics('settings', 'send-public-key-by-mail');
                 ox.registry.call('mail-compose', 'compose', { attachments: attachments })
                 .done(function () {
                     hideWait();
@@ -727,7 +759,7 @@ define('oxguard/pgp/settings/pane', [
 
     function formatKeyID (id) {
         if (id.length < 9) return (id);
-        return ('<span class="keystart">' + id.substring(0,8) + '</span><span class="keyend">' + id.substring(8) + '</span>');
+        return ('<span class="keystart">' + id.substring(0,(id.length - 8)) + '</span><span class="keyend">' + id.substring((id.length - 8)) + '</span>');
     }
 
     function formatFingerprint (fp) {
@@ -761,9 +793,7 @@ define('oxguard/pgp/settings/pane', [
             cid: ox.context_id,
             data: data
         };
-        $.post(ox.apiRoot + '/oxguard/settings?action=set&session=' + ox.session, JSON.stringify(json), function () {
-
-        })
+        http.post(ox.apiRoot + '/oxguard/settings?action=set', '', json)
         .fail (function () {
             require(['io.ox/core/notifications'], function (notify) {
                 notify.yell('error', gt('Failed to update settings'));
@@ -788,6 +818,32 @@ define('oxguard/pgp/settings/pane', [
             } else {
                 $('#pgpsign').prop('checked', false);
             }
+            if (settings.get('advanced')) {
+                $('#pgpadvanced').prop('checked', true);
+            } else {
+                $('#pgpadvanced').prop('checked', false);
+            }
+        }
+    }
+
+    function switchEmailType () {
+        if ($('#inlinedefault').is(':checked')) {
+            require (['settings!io.ox/mail'], function (s) {
+                if (s.get('messageFormat') !== 'text') {
+                    var dialog = new dialogs.CreateDialog({ width: 450, center: true,  enter: 'ok' });
+                    dialog.header($('<h4>').text(gt('Email format')));
+                    var instructions = $('<p>').append(gt('Emails that contain HTML and are sent with PGP Inline will often result in decoding errors and possible failure.  As a result, the default Email format should be changed to plaintext.  Click OK to change the default to plaintext, cancel to keep your current setting.'));
+                    dialog.getBody().append(instructions);
+                    dialog
+                    .addPrimaryButton('ok', gt('OK'), 'ok')
+                    .addButton('cancel', gt('Cancel'), 'cancel')
+                    .on('ok', function () {
+                        s.set('messageFormat', 'text');
+                        s.save();
+                    })
+                    .show();
+                }
+            });
         }
     }
 
@@ -804,17 +860,21 @@ define('oxguard/pgp/settings/pane', [
         sigdiv.click(function () {
             pGPSigndefault.click();
         });
-        var typediv = $('<span class="selectable">' + gt('PGP default to using PGP inline for compatibility') + '</span></br>');
+        var typediv = $('<span class="selectable">' + gt('Default to using PGP inline for new mails') + '</span></br>');
         var pgpType = $('<input type="checkbox" id="inlinedefault" style="margin-right:15px; margin-top:1px;">');
         typediv.click(function () {
             pgpType.click();
         });
-        optiondiv.append(makePGPdefault).append(defdiv).append(pGPSigndefault).append(sigdiv).append(pgpType).append(typediv);
+        optiondiv.append(makePGPdefault).append(defdiv).append(pGPSigndefault).append(sigdiv);
+        if (settings.get('advanced')) {
+            optiondiv.append(pgpType).append(typediv);
+        }
         makePGPdefault.click(function () {
             sendDefaults();
         });
         pgpType.click(function () {
             sendDefaults();
+            switchEmailType();
         });
         pGPSigndefault.click(function () {
             sendDefaults();
@@ -835,6 +895,35 @@ define('oxguard/pgp/settings/pane', [
         $('#og_wait').hide();
     }
 
+    function drawAdvanced () {
+        var header = $('<legend class="sectiontitle" style="margin-bottom:5px;">').append(gt('Advanced'));
+        var defaultsHeader = $('<div class="oxguard_settings defaults" style="line-height: 1.8em;"/>');
+        var useAdvanced = $('<input type="checkbox" id="pgpadvanced" class="pgpadvanced" style="margin-right:15px; margin-top:1px;">');
+        var optiondiv = $('<div>');
+        var advdiv = $('<span class="selectable pgpadvanced">' + gt('Enable Advanced PGP Features') + '</span></br>');
+        advdiv.click(function () {
+            useAdvanced.click();
+        });
+        useAdvanced.on('click', function () {
+            if ($('#pgpadvanced').is(':checked')) {
+                core.metrics('settings', 'select-advanced-mode');
+            } else {
+                core.metrics('settings', 'select-basic-mode');
+            }
+            settings.set('advanced', $('#pgpadvanced').is(':checked'));
+            settings.save();
+            redraw();
+        });
+        optiondiv.append(useAdvanced).append(advdiv);
+        return (defaultsHeader.append(header).append(optiondiv));
+    }
+
+    function drawVersion () {
+        if (_.device('small')) return ('');
+        var div = $('<div class="guardVersion">');
+        div.append(window.oxguarddata.version + '<br>build: ' + window.oxguarddata.server);
+        return (div);
+    }
     ///// Setup
 
     ext.point('oxguard/pgp/settings/detail').extend({
@@ -842,6 +931,7 @@ define('oxguard/pgp/settings/pane', [
         id: 'oxguardppgsettings',
         draw: function () {
             var node = this;
+            thisNode = this;
             util.hasSetupDone()
             .done(function () {
                 if (settings.get('cryptoProvider') === 'mailvelope') {
@@ -860,9 +950,15 @@ define('oxguard/pgp/settings/pane', [
         },
         save: _.noop
     });
+
+    function redraw() {
+        thisNode.empty();
+        thisNode.append(addSettings());
+    }
+
     function addSettings () {
         var holder = $('<div>').css('max-width', '800px');
-        var message = $('<span>').append(gt('PGP Encryption Settings'));
+        var message = $('<span>').append((settings.get('advanced') ? gt('PGP Encryption Settings') : gt('Security Settings')));
         message.append(new HelpView({
             base: 'help-guard',
             iconClass: 'guardhelp',
@@ -876,6 +972,11 @@ define('oxguard/pgp/settings/pane', [
             updateCheckboxes ();
         }, 20);
         setupWait();
-        return (holder.append(defaults).append(keys()).append(uploadPublic().append(pubkeys.listPublic('settings'))));
+        var settingsDiv = holder.append(defaults).append(keys());
+        if (settings.get('advanced')) {
+            settingsDiv.append(uploadPublic().append(pubkeys.listPublic('settings')));
+        }
+        settingsDiv.append(drawAdvanced()).append(drawVersion());
+        return (settingsDiv);
     }
 });
