@@ -20,7 +20,7 @@ define('oxguard/pgp/uploadkeys', [
             formData.append('password', guard);
         }
         var url = ox.apiRoot + '/oxguard/pgp?action=' + (priv ? 'uploadprivate' : 'uploadkeys') +
-        '&session=' + ox.session + '&userid=' + ox.user_id + '&cid=' + ox.context_id;
+        '&session=' + ox.session + '&userid=' + ox.user_id + '&cid=' + ox.context_id + '&language=' + ox.language;
         if (emailList !== undefined) {
             url = url + '&emailaddress=' + encodeURIComponent(emailList);
         }
@@ -38,6 +38,9 @@ define('oxguard/pgp/uploadkeys', [
                         var added = gt('Added keys: \r\n');
                         for (var i = 0; i < keys.length; i++) {
                             for (var j = 0; j < keys[i].length; j++) {
+                                for (var k = 0; k < keys[i][j].ids.length; k++) {  // Will be displaying as text, so convert from html markup
+                                    keys[i][j].ids[k] = $('<div/>').html(keys[i][j].ids[k]).text();
+                                }
                                 added = added + gt('Key ID: ') + keys[i][j].Key + ' ' + keys[i][j].ids + '\r\n';
                             }
                             added = added + '\r\n';
@@ -82,11 +85,24 @@ define('oxguard/pgp/uploadkeys', [
             var explain = $('<div><p>' + gt('Please enter passwords for the upload') + '</p>');
 
             var passdiv = $('<div>').addClass('row-fluid');
+            var newogpassword = $('<input name="guardpassword" type="password"/>');
+            var newogpassword2 = $('<input name="guardpassword2" type="password"/>');
+            var hint = $('<td>');
+            var pw1 = $('<tr>').append($('<td class="pw">').append('<em>' + gt('Enter new password for the key:') + '</em>')).append($('<td>').append(newogpassword));
+            var pw2 = $('<tr>').append($('<td class="pw">').append('<em>' + gt('Confirm Password:') + '</em>')).append($('<td>').append(newogpassword2));
+            var noSaveWorkAround = $('<input style="display:none" type="text" name="dontremember"/><input style="display:none" type="password" name="dontrememberpass"/>');
             var table = $('<table class="og_password_prompt"/>')
+            .append(noSaveWorkAround)
             .append('<tr><td class="pw"><em>' + gt('Private key password for the key you are uploading:') + '</em></td><td><input name="pgppassword" type="password"/></td></tr>')
-            .append('<tr><td class="pw"><em>' + gt('Enter new password for the key:') + '</em></td><td><input name="guardpassword" type="password"/></td></tr>');
+            .append(pw1)
+            .append(pw2)
+            .append($('<tr>').append('<td>').append(hint));
             var errormessage = $('<span id="uploaderror" style="color:red;"></span>');
             passdiv.append(table);
+            require (['oxguard/core/passwords'], function (pass) {
+                pass.passwordCheck(newogpassword, hint);
+                pass.passwordCompare(newogpassword2, newogpassword, hint);
+            });
             dialog.getBody().append(explain).append(passdiv).append(errormessage);
             dialog
             .addPrimaryButton('ok', gt('OK'), 'ok')
@@ -96,6 +112,11 @@ define('oxguard/pgp/uploadkeys', [
             .on('ok', function () {
                 var pgp = $('input[name="pgppassword"]').val();
                 var guard = $('input[name="guardpassword"]').val();
+                var guard2 = $('input[name="guardpassword2"]').val();
+                if (guard !== guard2) {
+                    uploadPrivate (files, gt('Passwords not equal'));
+                    return;
+                }
                 if (window.oxguarddata.settings.min_password_length !== undefined) {  // Check min password length
                     if (guard.trim().length < window.oxguarddata.settings.min_password_length) {
                         uploadPrivate (files, gt('New password must be at least %s characters long', window.oxguarddata.settings.min_password_length));
@@ -115,27 +136,7 @@ define('oxguard/pgp/uploadkeys', [
                 .fail(function (e) {
                     console.log(e);
                     deferred.reject(e.trim());
-                    if (e === 'duplicate') {
-                        notify.yell('error', gt('This key already exists'));
-                        return;
-                    }
-                    if (e === 'Bad pgp') {
-                        notify.yell('error', gt('Bad PGP Password'));
-                        return;
-                    }
-                    if (e === 'Bad password') {
-                        notify.yell('error', gt('Bad Password'));
-                        return;
-                    }
-                    if (e === 'Bad ID') {
-                        notify.yell('error', gt('The private key must have your primary email as a user ID'));
-                        return;
-                    }
-                    if (e === 'Bad Merge Password') {
-                        notify.yell('error', gt('Must use same password as existing key to merge'));
-                        return;
-                    }
-                    notify.yell('error', gt('Problem uploading Private Key ') + e);
+                    handleFail (e, notify);
                 });
             })
             .show(function () {
@@ -150,6 +151,30 @@ define('oxguard/pgp/uploadkeys', [
         return (deferred);
     }
 
+    function handleFail (e, notify) {
+        if (e === 'duplicate') {
+            notify.yell('error', gt('This key already exists'));
+            return;
+        }
+        if (e === 'Bad pgp') {
+            notify.yell('error', gt('Bad PGP Password'));
+            return;
+        }
+        if (e === 'Bad password') {
+            notify.yell('error', gt('Bad Password'));
+            return;
+        }
+        if (e === 'Bad ID') {
+            notify.yell('error', gt('The private key must have your primary email as a user ID'));
+            return;
+        }
+        if (e === 'Bad Merge Password') {
+            notify.yell('error', gt('Must use same password as existing key to merge'));
+            return;
+        }
+        notify.yell('error', gt('Problem uploading Private Key ') + e);
+    }
+
     return {
         upload: upload,
         uploadPrivate: uploadPrivate
