@@ -5,7 +5,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/register', [
     'io.ox/core/extensions',
@@ -16,16 +16,29 @@ define('oxguard/register', [
 ], function (ext, oxguard, gt, settings) {
     'use strict';
 
+    var productName = ox.serverConfig['guard.productName'] === undefined ? settings.get('productName') : ox.serverConfig['guard.productName'];
+    if (productName === undefined || productName === 'undefined' || productName === '') {
+        productName = 'Guard';
+    }
+
     var oxguarddata = {
         passcode: null,
         settings:  {},
-        version: '2.2.1-rc3'
+        version: '2.4.2-3493',
+        productName: oxguard.sanitize(productName)
     };
+
     window.oxguarddata = oxguarddata;
 
     // Login section
     sendauth(''); // initial login, no password yet
 
+    // Default settings if needed
+    if (settings.get('advanced') === undefined) {
+        settings.set('advanced', settings.get('defaultAdvanced') ? true : false);
+        settings.save();
+    }
+
     function sendauth(pass) {
         oxguard.auth(ox.user_id, pass)
         .done(function (data) {
@@ -34,7 +47,6 @@ define('oxguard/register', [
                 if (data.auth.length > 20) {// If good code comes back, then store userid
                     oxguarddata.userid = ox.user_id;
                     oxguarddata.passcode = data.auth;
-                    $('.og_signout').show();
                 } else {// If bad code, then log and mark oxguard.user_id as -1
                     if ((data.auth.indexOf('Bad') > -1) || (data.auth.indexOf('Lockout') > -1)) {
                         oxguarddata.passcode = null;
@@ -50,7 +62,7 @@ define('oxguard/register', [
                 }
                 if (ox.context_id === 0) ox.context_id = data.cid; // If the cid wasn't loaded, update from backend
                 oxguarddata.baton = window.oxguarddata.baton;
-                oxguarddata.recovery = data.recoveryAvail;
+                oxguarddata.recovery = data.recoveryAvail === undefined ? !data.noRecovery : data.recoveryAvail;
                 window.oxguarddata = oxguarddata;
 
                 if (sessionStorage !== null) {// If we were passed login info from login screen
@@ -71,24 +83,36 @@ define('oxguard/register', [
             }
         })
         .fail(function () {
-            $('.og_signout').hide();
             console.debug('Unable to connect to the encryption server');
         });
     }
 
     ext.point('io.ox/core/logout').extend({
         id: 'logoutOG',
+        index: 1,
         logout: function () {
-            // force save requests for all pending settings
-            var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id;
+            return doLogout();
+        }
+    });
+
+    function doLogout () {
+        var def = $.Deferred();
+        var params = '&userid=' + ox.user_id + '&cid=' + ox.context_id + '&session=' + ox.session;
+        oxguard.saveAuthToSession('', -1)  // destroy auth token
+        .always(function () { // Destroy Guard mapping and auth-token
             $.get(ox.apiRoot + '/oxguard/login?action=logout' + params, function () {
-                window.oxguarddata = null;
+                window.oxguarddata.passcode = null;
             })
             .fail(function () {
                 console.log('Fail logout oxguard');
+            })
+            .always(function () {
+                def.resolve();
             });
-        }
-    });
+        });
+
+        return def;
+    }
 
     ext.point('io.ox/core/topbar/right/dropdown').extend({
         id: 'guard-guided-tour',
@@ -96,7 +120,8 @@ define('oxguard/register', [
         draw: function () {
             this.append(
                 $('<li class="og_tour">').append(
-                    $('<a href="#" data-action="guard-tour" role="menuitem" tabindex="1">').text(gt('Guided tour for Guard'))
+                    //#. %s product name
+                    $('<a href="#" data-action="guard-tour" role="menuitem" tabindex="1">').text(gt('Guided tour for %s', window.oxguarddata.productName))
                 )
                 .on('click', function (e) {
                     e.preventDefault();
@@ -112,30 +137,32 @@ define('oxguard/register', [
         id: 'logoutOG',
         index: 990,
         draw: function () {
+            var dropdown = this.parent();
+            dropdown.on('show.bs.dropdown', function () {
+                var pass = window.oxguarddata.passcode;
+                if (pass && pass.length > 10) {
+                    $('.og_signout').show();
+                } else {
+                    $('.og_signout').hide();
+                }
+            });
             this.append(
                 $('<li class="divider og_signout" aria-hidden="true" role="presentation"></li>'),
                 $('<li class="og_signout">').append(
-                    $('<a href="#" data-action="logout" role="menuitem" tabindex="1">').text(gt('Sign out Guard'))
+                    //#. %s product name
+                    $('<a href="#" data-action="logout" role="menuitem" tabindex="1">').text(gt('Sign out %s', window.oxguarddata.productName))
                 )
                 .on('click', function (e) {
                     e.preventDefault();
                     window.oxguarddata.passcode = null;
-                    $('.og_signout').hide();
+                    doLogout();
                 })
             );
             var auth = window.oxguarddata.passcode;
             if (auth === null || auth === undefined) {
-                hideLogout();
                 return;
             }
-            if (auth.length < 20) hideLogout();
         }
     });
 
-    function hideLogout() {
-        window.setTimeout(function () {
-            $('.og_signout').hide();
-        },100);
-    }
-
 });
