@@ -5,7 +5,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * Copyright (C) Open-Xchange Inc., 2006-2011
+ * Copyright (C) 2016-2020 OX Software GmbH
  */
 define('oxguard/settings', [
     'io.ox/core/extensions',
@@ -16,7 +16,8 @@ define('oxguard/settings', [
     // Add settings for encryption to the Settings Page
     ext.point('io.ox/settings/pane/main').extend({
         id: 'oxguard',
-        title: gt.pgettext('app', 'Guard Security'),
+        //#. %s product Name
+        title: gt.format(gt.pgettext('app', '%s Security'), window.oxguarddata.productName),
         index: 600,
         loadSettingPane: true
     });
