@@ -4,15 +4,14 @@ define('oxguard/settings/defaults', [
 ], function (api, capabilities) {
     'use strict';
 
-    var guardSetUp = window.oxguarddata && window.oxguarddata.passcode === 'No key';
-
     function getDefault () {
         if (!api.isMailvelopeSupported()) {
             return 'guard';
-        } else if (!capabilities.has('guard') || (capabilities.has('forceMailvelope') && !guardSetUp)) {
+        } else if (!capabilities.has('guard')) {
             // We only force Mailvelope if Guard not yet set up
             return 'mailvelope';
         }
+        return undefined;
     }
 
     return {
