@@ -4,10 +4,12 @@ define('oxguard/settings/pane', [
     'oxguard/crypto/encr',
     'oxguard/core/og_http',
     'oxguard/util',
+    'oxguard/core/emailverify',
     'io.ox/backbone/mini-views/help',
+    'oxguard/oxguard_core',
     'gettext!oxguard',
     'settings!oxguard'
-], function (ext, dialogs, encr, og_http, util, HelpView, gt, settings) {
+], function (ext, dialogs, encr, og_http, util, verify, HelpView, core, gt, settings) {
     'use strict';
 
     function setupGuard (where) {
@@ -15,19 +17,20 @@ define('oxguard/settings/pane', [
             $('<div class="oxguard_settings"/>')
             .append('<legend class="sectiontitle">' + gt('Get Started') + '</legend></br>');
         var instructions = $('<div>');
-        instructions.append('<p>' + gt('In order to start with Guard Security, you must set up a password for your secured files.') + '</p>');
+        //#. product name
+        instructions.append('<p>' + gt('In order to start with %s Security, you must set up a password for your secured files.', window.oxguarddata.productName) + '</p>');
         var startButton = $('<button type="button" class="btn btn-primary">' + gt('Start') + '</button>');
         startButton.click (function () {
-            require(['oxguard/oxguard_core'], function (oxguard) {
-                oxguard.createKeysWizard()
-                .done(function (result) {
-                    if (result === 'OK') draw(where);
-                    //$('.oxguard_settings').replaceWith(addSettings());
-                });
+            core.metrics('settings', 'create-keys');
+            core.createKeysWizard()
+            .done(function (result) {
+                if (result === 'OK') draw(where);
+                //$('.oxguard_settings').replaceWith(addSettings());
             });
         });
         var holder = $('<div>').css('max-width', '800px');
-        holder.append('<h1>' + gt('Guard Security Settings') + '</h1><br/>');
+        //#. %s product name
+        holder.append('<h1>' + gt('%s Security Settings', window.oxguarddata.productName) + '</h1><br/>');
         where.append(holder.append(passheader.append(instructions).append(startButton)));
     }
 
@@ -35,36 +38,60 @@ define('oxguard/settings/pane', [
         var passheader =
         $('<div class="oxguard_settings password"/>')
         .append('<legend class="sectiontitle">' + gt('Password') + '</legend></br>')
-        .append('<span> ' + gt('Change Guard Security Password.') + '</span><br/>');
-        var newpass1 = $('<input type="password" name="newpass1"/>');
+        //#. %s product name
+        .append('<span> ' + gt('Change %s Security Password.', window.oxguarddata.productName) + '</span><br/>');
+        var newpass1 = $('<input type="password" name="newpass1" autocomplete="off"/>');
         var td = $('<td>').append(newpass1);
-        var newpass2 = $('<input type="password" name="newpass2"/>');
+        var newpass2 = $('<input type="password" name="newpass2" autocomplete="off"/>');
         var td2 = $('<td>').append(newpass2);
-        var hint = $('<td>');
-        var passwordTable = $('<table/>')
-        .append('<tr><td><span>' + gt('Enter current Guard security password') + ': </span></td><td><input type="password" name="oldpass" /><td><td></td></tr>')
-        .append($('<tr><td><span>' + gt('Enter new Guard security password') + ': </span></td></tr>').append(td).append(hint))
-        .append($('<tr><td><span>' + gt('Verify new Guard security password') + ':</span></td></tr>').append(td2).append('<td></td>'));
-        var errorDiv = $('<div id="grdsettingerror" class="alert alert-info" style="display:none"/>');
+        var hint = $('<td style="width:150px;">');
+        var curPrompt = $('<span>').append(gt('Enter current %s security password', window.oxguarddata.productName));
+        var prompt1 = $('<span>').append(gt('Enter new %s security password', window.oxguarddata.productName));
+        var prompt2 = $('<span>').append(gt('Verify new %s security password', window.oxguarddata.productName));
+        var oldpass = $('<input type="password" name="oldpass" autocomplete="off" />');
+        var passwordTable;
+        if (_.device('small')) {
+            passwordTable = $('<div style="padding:10px;">');
+            if (!window.oxguarddata['new']) {
+                passwordTable        //#. %s product name
+                .append(curPrompt).append('<br>').append(oldpass).append('<br>');
+            }
+            passwordTable
+            .append(prompt1).append('<br>').append(newpass1).append('<br>')
+            .append(prompt2).append('<br>').append(newpass2);
+        } else {
+            passwordTable = $('<table/>');
+            if (!window.oxguarddata['new']) {
+                passwordTable        //#. %s product name
+                .append($('<tr>').append(($('<td>').append(curPrompt))).append($('<td>').append(oldpass)));
+            }
+            passwordTable
+            .append($('<tr>').append(($('<td>').append(prompt1))).append(td).append(hint))
+            .append($('<tr>').append(($('<td>').append(prompt2))).append(td2).append($('<td>')));
+        }
+
         require (['oxguard/core/passwords'], function (pass) {
             pass.passwordCheck(newpass1, hint);
             pass.passwordCompare(newpass2, newpass1, hint);
         });
-        var passButton = $('<button type="button" class="btn btn-primary">' + gt('Change Guard security password') + '</button>');
+        //#. %s product name
+        var passButton = $('<button type="button" class="btn btn-primary" style="margin-top:10px;">' + gt('Change %s security password', window.oxguarddata.productName) + '</button>');
         passButton.click(passChanged);
 
-        return (passheader.append(passwordTable).append(errorDiv).append(passButton));
+        return (passheader.append(passwordTable).append(passButton));
     }
 
     function createPasswordReset() {
-        if (!window.oxguarddata.recovery) {  // If no recovery avail, then don't display reset button
+        if (!window.oxguarddata.recovery || window.oxguarddata['new']) {  // If no recovery avail, then don't display reset button
             return ('');
         }
         var passheader =
             $('<div class="oxguard_settings password password-reset"/>')
-            .append('<legend class="sectiontitle">' + gt('Reset Guard security password') + '</legend></br>')
-            .append('<span> ' + gt('Send a temporary Guard security password to my secondary Email address.') + '</span><br/>');
-        var passButton = $('<button type="button" class="btn btn-primary">' + gt('Reset Guard security password') + '</button>');
+            //#. %s product name
+            .append('<legend class="sectiontitle">' + gt('Reset %s security password', window.oxguarddata.productName) + '</legend></br>')
+            .append('<span> ' + gt('Send a temporary %s security password to my secondary Email address.', window.oxguarddata.productName) + '</span><br/>');
+        //#. %s product name
+        var passButton = $('<button type="button" class="btn btn-primary" style="margin-top:10px;">' + gt('Reset %s security password', window.oxguarddata.productName) + '</button>');
         passButton.click(doReset);
         return (passheader.append(passButton));
     }
@@ -83,15 +110,16 @@ define('oxguard/settings/pane', [
     }
 
     function doDeleteRecovery() {
-        require (['oxguard/oxguard_core', 'io.ox/core/notifications'], function (core, notify) {
-            core.getPassword(gt('Please verify your password before deleting the recovery'))
+        require (['io.ox/core/notifications'], function (notify) {
+            core.getPassword(gt('Please verify your password before deleting the recovery.'))
             .done (function (e) {
                 var data = {
                     userid: ox.user_id,
                     cid: ox.context_id,
-                    password: e
+                    password: e.password
                 };
-                og_http.post(ox.apiRoot + '/oxguard/login?action=deleterecovery&session=' + ox.session, '', data)
+                core.metrics('settings', 'delete-recovery');
+                og_http.post(ox.apiRoot + '/oxguard/login?action=deleterecovery', '', data)
                 .done (function () {
                     notify.yell('success', gt('Recovery deleted'));
                     window.oxguarddata.recovery = false;
@@ -111,23 +139,49 @@ define('oxguard/settings/pane', [
     function createSecondaryChange() {
         if (window.oxguarddata.settings.noRecovery === true || window.oxguarddata.recovery === false) return;  // Don't display secondary email if no recovery is set
         updateEmail();
+        var current = $('<span>').append(gt('Current Email address:'));
+        var currentEmail = $('<span id="currentsecondary" style="padding-left:20px;">');
         var emailheader =
             $('<div class="oxguard_settings"/>')
             .append('<legend class="sectiontitle">' + gt('Secondary Email') + '</legend></br>')
-            .append('<span> ' + gt('Change Email address used for password reset.') + '</span><br/><br/>')
-            .append('<span>' + gt('Current Email address:') + '</span><span id="currentsecondary" style="padding-left:20px;"></span>');
-        var emailTable = $('<table/>')
-            .append('<tr><td><span>' + gt('Enter current Guard security password') + ': </span></td><td><input type="password" name="ogpass" /><td></tr>')
-            .append('<tr><td><span>' + gt('Enter new secondary Email address') + ': </span></td><td><input name="newemail"/><td></tr>');
+            .append('<span> ' + gt('Change Email address used for password reset.') + '</span><br/><br/>');
+        if (_.device('small')) {
+            emailheader.append(current).append('<br>').append(currentEmail);
+        } else {
+            emailheader.append(current).append(currentEmail);
+        }
+        var noSaveWorkAround = $('<input style="display:none" type="text" name="dontremember"/><input style="display:none" type="password" name="dontrememberpass"/>');
+        var emailPass = $('<input name="newemail"/>');
+        var verifyPass = $('<input name="newemailverify">');
+        var currentPrompt = $('<span>').append(gt('Enter current %s security password', window.oxguarddata.productName));
+        var currentInput = $('<input type="password" name="ogpass" autocomplete="off"/>');
+        var newPrompt = $('<span>').append(gt('Enter new secondary Email address'));
+        var verifyPrompt = $('<span>').append(gt('Verify Email address'));
+        var hint = $('<td>');
+        var emailTable;
+        if (_.device('small')) {
+            emailTable = $('<div style="margin-top:15px;margin-left:10px;">')
+            .append(currentPrompt).append('<br>').append(currentInput).append('<br>')
+            .append(newPrompt).append('<br>').append(emailPass).append('<br>')
+            .append(verifyPrompt).append('<br>').append(verifyPass);
+        } else {
+            emailTable = $('<table/>')
+            .append(noSaveWorkAround)
+            //#. %s product name
+            .append($('<tr>').append($('<td>').append(currentPrompt)).append($('<td>').append(currentInput)))
+            .append($('<tr>').append($('<td>').append(newPrompt)).append($('<td>').append(emailPass)).append(hint))
+            .append($('<tr>').append($('<td>').append(verifyPrompt)).append($('<td>').append(verifyPass)));
+        }
         var errorDiv = $('<div id="newemailerror" class="alert alert-info" style="display:none"/>');
         var emailButton = $('<button type="button" class="btn btn-primary">' + gt('Change Email address') + '</button>');
-
+        verify.setValidate(emailPass, hint);
+        verify.autoCompare(emailPass, verifyPass, hint);
         emailButton.click(emailChanged);
         return (emailheader.append(emailTable).append(errorDiv).append(emailButton));
     }
 
     function updateEmail () {
-        og_http.get(ox.apiRoot + '/oxguard/login?action=secondary', '&session=' + ox.session + '&userid=' + ox.user_id + '&cid=' + ox.context_id)
+        og_http.get(ox.apiRoot + '/oxguard/login?action=secondary', '&userid=' + ox.user_id + '&cid=' + ox.context_id)
         .done(function (d) {
             d = d.trim();
             if (d.length < 2) {
@@ -141,10 +195,13 @@ define('oxguard/settings/pane', [
 
     function emailChanged () {
         var email = $('input[name="newemail"]').val();
-        if (!validateEmail(email)) {
-            $('#newemailerror').html(gt('Invalid email address'));
-            $('#newemailerror').focus();
-            showError('newemailerror');
+        var verifyEmail = $('input[name="newemailverify"]').val();
+        if (email !== verifyEmail) {
+            showError(gt('Emails not equal'));
+            return;
+        }
+        if (!verify.validate(email)) {
+            showError(gt('Invalid email address'));
         } else {
             var data = {
                 userid: ox.user_id,
@@ -152,17 +209,18 @@ define('oxguard/settings/pane', [
                 email: email,
                 password: $('input[name="ogpass"]').val()
             };
-            $.post(ox.apiRoot + '/oxguard/login?action=changesecondary&session=' + ox.session, JSON.stringify(data), function () {
-                $('#newemailerror').html(gt('Changed'));
-                showError('newemailerror');
+            core.metrics('settings', 'change-secondary-email');
+            og_http.post(ox.apiRoot + '/oxguard/login?action=changesecondary', '', data)
+            .done(function () {
+                showOK(gt('Successfully changed email address'));
                 updateEmail();
                 $('input[name="ogpass"]').val('');
                 $('input[name="newemail"]').val('');
+                $('input[name="newemailverify"]').val('');
             })
             .fail(function (d) {
                 if (d.responseText.trim() === 'Bad password') {
-                    $('#newemailerror').html(gt('Bad Password'));
-                    showError('newemailerror');
+                    showError(gt('Bad Password'));
                     if (!_.device('ios')) {
                         $('input[name="ogpass"]').focus();
                     }
@@ -171,16 +229,16 @@ define('oxguard/settings/pane', [
         }
     }
 
-    function showError(id) {
-        $('#' + id).show();
-        window.setTimeout(function () {
-            $('#' + id).hide();
-        }, 10000);
+    function showOK (msg) {
+        require(['io.ox/core/notifications'], function (notify) {
+            notify.yell('success', msg);
+        });
     }
 
-    function validateEmail(email) {
-        var re = /^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
-        return re.test(email);
+    function showError (msg) {
+        require(['io.ox/core/notifications'], function (notify) {
+            notify.yell('error', msg);
+        });
     }
 
     function doReset() {
@@ -191,32 +249,34 @@ define('oxguard/settings/pane', [
                 waitdiv.append('<i class="fa-key icon-key fa fa-spin icon-spin"/><span>' + gt('Generating key, Please wait') + '</span>');
                 $('.window-container-center').append(waitdiv);
                 waitdiv.show();
-                var param = '&session=' + ox.session + '&userid=' + ox.user_id + '&cid=' + ox.context_id +
+                var param = '&userid=' + ox.user_id + '&cid=' + ox.context_id +
                 '&default=' + encodeURIComponent(primaryEmail) + '&lang=' + ox.language;
+                core.metrics('settings', 'reset-password');
                 og_http.get(ox.apiRoot + '/oxguard/login?action=reset', param)
                 .done(function (data) {
                     $('.og_wait').remove();
+                    core.removeAuth();
                     require(['io.ox/core/notifications'], function (notify) {
                         if (data.indexOf('primary') >= 0) {
-                            notify.yell('success', gt('A new password has been sent to your email address'));
+                            notify.yell('success', gt('A new password has been sent to your email address.'));
                             window.oxguarddata.passcode = 'Password Needed';
                             return;
                         }
                         if (data.indexOf('ok') >= 0) {
-                            notify.yell('success', gt('A new password has been sent to your secondary email address'));
+                            notify.yell('success', gt('A new password has been sent to your secondary email address.'));
                             window.oxguarddata.passcode = 'Password Needed';
                             return;
                         }
                         if (data.trim() === 'NoRecovery') {
-                            notify.yell('error', gt('No password recovery is available'));
+                            notify.yell('error', gt('No password recovery is available.'));
                             return;
                         }
                         if (data.indexOf('FailNotify') >= 0) {
-                            notify.yell('error', gt('Password reset, but unable to send to your email address'));
+                            notify.yell('error', gt('Password reset, but unable to send to your email address.'));
                             return;
                         }
                         if (data.indexOf('NoSecondary') >= 0) {
-                            notify.yell('error', gt('Unable to find email address to send password reset'));
+                            notify.yell('error', gt('Unable to find email address to send password reset.'));
                             return;
                         }
                         notify.yell('error', gt('Unable to reset your password'));
@@ -239,8 +299,7 @@ define('oxguard/settings/pane', [
         var min = window.oxguarddata.settings.min_password_length;
         if (min !== undefined) {
             if (newpass.val().length < min) {
-                $('#grdsettingerror').text(gt('New password must be at least %s characters long', min));
-                $('#grdsettingerror').show();
+                showError(gt('New password must be at least %s characters long', min));
                 if (!_.device('ios')) {
                     newpass.focus();
                 }
@@ -254,7 +313,7 @@ define('oxguard/settings/pane', [
             newpass2.css('background-color', 'white');
             var userdata = {
                     newpass: newpass.val(),
-                    oldpass: $('input[name="oldpass"]').val().trim(),
+                    oldpass: ($('input[name="oldpass"]').val() === undefined ? '' : $('input[name="oldpass"]').val().trim()),
                     user_id: ox.user_id,
                     sessionID: ox.session,
                     cid: ox.context_id,
@@ -264,17 +323,25 @@ define('oxguard/settings/pane', [
             waitdiv.append('<i class="fa-key icon-key fa fa-spin icon-spin"/><span>' + gt('Generating key, Please wait') + '</span>');
             $('.window-container-center').append(waitdiv);
             waitdiv.show();
-            $.post(ox.apiRoot + '/oxguard/login?action=changepass&session=' + ox.session, JSON.stringify(userdata), function (data) {
+            core.metrics('settings', 'change-password');
+            og_http.post(ox.apiRoot + '/oxguard/login?action=changepass', '', userdata)
+            .done(function (data) {
                 $('.og_wait').remove();
                 if (typeof data === 'string') data = $.parseJSON(data);
+                if (data.auth === undefined) {
+                    require(['oxguard/core/errorHandler'], function (err) {
+                        err.showError(data);
+                    });
+                    return;
+                }
                 if (data.auth === 'Bad password') {
-                    $('#grdsettingerror').text(gt('Bad password'));
+                    showError(gt('Bad password'));
                 }
                 if (data.auth === 'Lockout') {
-                    $('#grdsettingerror').text(gt('Temporary Lockout'));
+                    showError(gt('Temporary Lockout'));
                 }
                 if (data.auth === 'Bad new password') {
-                    $('#grdsettingerror').text(gt('New password must be at least %s characters long', data.minlength));
+                    showError(gt('New password must be at least %s characters long', data.minlength));
                 }
                 if (data.auth.length > 20) {
                     $('input[name="newpass1"]').val('');
@@ -282,13 +349,11 @@ define('oxguard/settings/pane', [
                     $('input[name="oldpass"]').val('');
                     window.oxguarddata.passcode = null;
                     window.oxguarddata.recovery = data.recovery;
+                    window.oxguarddata['new'] = false;
                     redraw();
-                    $('#grdsettingerror').text(gt('Success'));
+                    showOK(gt('Password changed successfully'));
+                    core.removeAuth(); // We want to remove rembered auth codes, as the password has changed
                 }
-                $('#grdsettingerror').show();
-                window.setTimeout(function () {
-                    $('#grdsettingerror').hide();
-                }, 10000);
             })
             .fail(function (e) {
                 $('.og_wait').remove();
@@ -296,8 +361,7 @@ define('oxguard/settings/pane', [
                 if (e.responseText.trim() === 'Bad Password') {
                     error = gt('Bad password');
                 }
-                $('#grdsettingerror').text(error);
-                $('#grdsettingerror').show();
+                showError(error);
             });
             return;
         }
@@ -340,7 +404,8 @@ define('oxguard/settings/pane', [
 
     function addSettings () {
         var holder = $('<div id="guard_settings">').css('max-width', '800px');
-        var message = $('<span>').append(gt('Guard Security Settings'));
+        //#. %s product name
+        var message = $('<span>').append(gt('%s Security Settings', window.oxguarddata.productName));
         message.append(new HelpView({
             base: 'help-guard',
             iconClass: 'guardhelp',
