@@ -2,13 +2,18 @@ define('oxguard/tour/main', [
     'io.ox/core/tk/wizard',
     'oxguard/oxguard_core',
     'oxguard/util',
+    'io.ox/core/capabilities',
     'io.ox/backbone/mini-views/help',
+    'settings!oxguard',
     'gettext!oxguard/tour'
-], function (Tour, core, util, HelpView, gt) {
+], function (Tour, core, util, capabilities, HelpView, settings, gt) {
     'use strict';
 
     function writeMail() {
-        ox.registry.call('mail-compose', 'compose');
+        ox.registry.call('mail-compose', 'compose')
+        .done(function (e) {
+            e.app.model.set('encrypt', true);
+        });
     }
 
     function openFiles() {
@@ -35,17 +40,27 @@ define('oxguard/tour/main', [
         priority: 1
     }, function () {
         if (!util.isGuardConfigured()) {
+            require(['settings!oxguard'], function (settings) {
+                settings.set('cryptoProvider', 'guard').save();
+            });
             Tour.registry.run('default/oxguard/createKeys');
             return;
         }
 
         var tour = new Tour(),
             composeApp;
+        var driveText = '';
+        var resetText = '';
+        // Select text depending on if recovery is available
+        if (window.oxguarddata.recoveryAvail) {
+            resetText = gt.format(gt.pgettext('tour', 'You already set up your %s account. But you can always change your encryption password, or request a temporary password if you forget it.'), window.oxguarddata.productName);
+        } else {
+            resetText = gt.format(gt.pgettext('tour', 'You already set up your %s account.  You can change your encryption password here.'), window.oxguarddata.productName);
+        }
 
-        tour.step()
-            .title(gt.pgettext('tour', 'The Guard module'))
+        tour.step({ labelNext: gt('Next') })
+            .title(gt.format(gt.pgettext('tour', 'The %s module'), window.oxguarddata.productName))
             .content(gt.pgettext('tour', 'Security and privacy matters to everyone. That\'s why you can now send and receive encrypted emails by simply clicking on the lock icon.'))
-            .hotspot('#statuslock')
             .waitFor('.og-ready')
             .on('wait', function () {
                 if (!composeApp) {
@@ -54,18 +69,25 @@ define('oxguard/tour/main', [
                         composeApp = app;
                         //HACK: can not detect that mail compose window is rendered
                         composeApp.view.$el.addClass('og-ready');
+                        window.setTimeout(function () {
+                            tour.addHotspot('.toggle-encryption', { 'top': 14, 'left': 14 });
+                            composeApp.view.$el.find('.toggle-encryption .fa').click();
+                        }, 500);
+                    });
+                    ox.registry.call('mail-compose', 'compose').done(function (e) {
+                        composeApp = e.app;
+                        composeApp.cid = 'compose.tour'; // Assign a CID for the app
                     });
-                    ox.registry.call('mail-compose', 'compose');
                 } else {
                     ox.ui.App.reuse(composeApp.cid);
                 }
             })
             .on('next', function () {
-                $('#statuslock.icon-unlock').click();
+                composeApp.view.$el.find('.toggle-encryption .fa').click();
             })
             .end();
         tour.once('stop', function () {
-            if (composeApp) {
+            if (composeApp && composeApp.model) {
                 //prevent app from asking about changed content
                 composeApp.model.dirty(false);
                 composeApp.quit();
@@ -74,8 +96,9 @@ define('oxguard/tour/main', [
 
         tour
         .step()
-            .title(gt.pgettext('tour', 'Guard Security Settings'))
-            .content(gt.pgettext('tour', 'You already set up your Guard account. But you can always change your encryption password, or request a temporary password if you forget it.'))
+            //#. %s product Name
+            .title(gt.format(gt.pgettext('tour', '%s Security Settings'), window.oxguarddata.productName))
+            .content(resetText)
             .on('wait', function () {
                 ox.launch('io.ox/settings/main', { id: 'oxguard' }).then(function () {
                     this.setSettingsPane({ id: 'oxguard' });
@@ -85,8 +108,10 @@ define('oxguard/tour/main', [
             .spotlight('.oxguard_settings.password')
             .end()
         .step()
-            .title(gt.pgettext('tour', 'PGP Encryption Settings'))
-            .content(gt.pgettext('tour', 'From here you can update your encryption settings. For example you can choose to send encrypted emails by default.'))
+            .title((settings.get('advanced') ? gt.pgettext('tour', 'PGP Encryption Settings') : gt.pgettext('tour', 'Security Settings')))
+            .content((settings.get('advanced') ?
+                    gt.pgettext('tour', 'From here you can update your encryption settings. For example you can choose to send encrypted emails by default.') :
+                    gt.pgettext('tour', 'From here, you can update your security settings.  For example, you can choose to send secure emails by default.')))
             .on('wait', function () {
                 ox.launch('io.ox/settings/main', { id: 'oxguard/pgp' }).then(function () {
                     this.setSettingsPane({ id: 'oxguard/pgp' });
@@ -94,7 +119,7 @@ define('oxguard/tour/main', [
             })
             .waitFor('.oxguard_settings.defaults')
             .spotlight('.oxguard_settings.defaults')
-            .hotspot('.oxguard_settings.defaults #pgpdefault')
+            .hotspot('.oxguard_settings.defaults #pgpdefault', { 'top': 5, 'left': 5 })
             .end()
         .step()
             .title(gt.pgettext('tour', 'Signature'))
@@ -106,11 +131,12 @@ define('oxguard/tour/main', [
             })
             .waitFor('.oxguard_settings.defaults')
             .spotlight('.oxguard_settings.defaults')
-            .hotspot('.oxguard_settings.defaults #pgpsign')
-            .end()
-        .step()
+            .hotspot('.oxguard_settings.defaults #pgpsign', { 'top': 5, 'left': 5 })
+            .end();
+        if (settings.get('advanced')) {
+            tour.step()
             .title(gt.pgettext('tour', 'Alternative: PGP Inline'))
-            .content(gt.pgettext('tour', 'By default Guard sends encrypted emails using PGP/Mime format. To communicate with some systems you may need to use PGP Inline.'))
+            .content(gt.format(gt.pgettext('tour', 'By default %s sends encrypted emails using PGP/Mime format. To communicate with some systems you may need to use PGP Inline.'), window.oxguarddata.productName))
             .on('wait', function () {
                 ox.launch('io.ox/settings/main', { id: 'oxguard/pgp' }).then(function () {
                     this.setSettingsPane({ id: 'oxguard/pgp' });
@@ -118,9 +144,9 @@ define('oxguard/tour/main', [
             })
             .waitFor('.oxguard_settings.defaults')
             .spotlight('.oxguard_settings.defaults')
-            .hotspot('.oxguard_settings.defaults #inlinedefault')
+            .hotspot('.oxguard_settings.defaults #inlinedefault', { 'top': 5, 'left': 5 })
             .end()
-        .step()
+            .step()
             .title(gt.pgettext('tour', 'Advanced Settings'))
             .content(gt.pgettext('tour', 'Advanced users can manage their key lists from the PGP Encryption Settings.'))
             .on('wait', function () {
@@ -130,40 +156,63 @@ define('oxguard/tour/main', [
             })
             .waitFor('.oxguard_settings.keys')
             .spotlight('.oxguard_settings.keys')
-            .end()
+            .end();
+        } else {
+            tour
+            .step()
+            .title(gt.pgettext('tour', 'Advanced User Settings'))
+            .content($('<div>').append(
+                    $('<p>').text(gt.pgettext('tour', 'Enabling Advanced PGP Features will enable key management and specifying sending formats.'))
+             ))
+             .waitFor('.pgpadvanced')
+             .hotspot('.pgpadvanced', { 'top': 5, 'left': 5 })
+             .spotlight('.selectable.pgpadvanced')
+             .end();
+        }
+        tour
         .step()
-            .title(gt.pgettext('tour', 'Remove encryption'))
+            .title(gt.pgettext('tour', 'Enabling and disabling encryption'))
             .content($('<div>').append(
                 $('<p>').text(gt.pgettext('tour', 'You are now able to send secure emails.')),
-                $('<p>').text(gt.pgettext('tour', 'Removing the encryption is easy, too: Simply click on the lock icon again.'))
+                $('<p>').text(gt.pgettext('tour', 'Sending without encryption is easy, too: Simply click on the lock icon again.'))
             ))
             .on('wait', function () {
                 ox.ui.App.reuse(composeApp.cid);
+                window.setTimeout(function () {
+                    tour.addHotspot('.toggle-encryption', { 'top': 14, 'left': 14 });
+                    composeApp.model.set('encrypt', false);
+                }, 500);
             })
             .hotspot(['#statuslock'])
-            .waitFor('.og-ready')
-            .on('next', function () {
-                $('#statuslock.icon-lock').click();
-            })
-            .end()
-        .step()
+            .waitFor('.toggle-encryption .fa')
+            .end();
+        if (capabilities.has('guard-drive')) {
+            tour.step()
             .title(gt.pgettext('tour', 'Encrypt files'))
             .content(gt.pgettext('tour', 'You can also protect your files. Just click on Encrypt and the selected file will be stored securely.'))
             .navigateTo('io.ox/files/main')
-            .waitFor('.classic-toolbar')
+            .waitFor('.file-list-view')
             .hotspot('.classic-toolbar a[data-action=encrypt]')
             .on('wait', function () {
-                $('.file-list-view > .list-item.selectable:not(.file-type-folder):not(.file-type-guard):first').click();
-                $('.classic-toolbar [data-action=more] ~ ul').css('display', 'block');
+                window.setTimeout(function () {
+                    $('.file-list-view > .list-item.selectable:not(.file-type-folder):not(.file-type-guard):first').click();
+                    window.setTimeout(function () {
+                        $('.classic-toolbar [data-action=more] ~ ul').css('display', 'block');
+                        tour.addHotspot('.classic-toolbar a[data-action=encrypt]');
+                    }, 500);
+                }, 500);
             })
             .on('hide', function () {
                 $('.classic-toolbar [data-action=more] ~ ul').css('display', '');
             })
-            .end()
+            .end();
+            driveText = $('<p>').append($('<a href="#">').click(openFiles).text(gt.pgettext('tour', 'Encrypt your sensitive files in Drive')));
+        }
+        tour
         .step()
             .title(gt.pgettext('tour', 'Restart Guided Tour'))
             .content(gt.pgettext('tour', '<em>Hint:</em> you can start guided tours, any time you need them, from the system menu.'))
-            .hotspot('[data-action="guard-tour"]')
+            .hotspot('[data-action="guard-tour"]', { 'top': 13, 'left': 10 })
             .referTo('#topbar-settings-dropdown')
             .waitFor('#topbar-settings-dropdown')
             .on('wait', function () {
@@ -178,8 +227,11 @@ define('oxguard/tour/main', [
             .content($('<div>').append(
                 $('<p>').text(gt.pgettext('tour', 'You successfully learned how to protect your emails and files.')),
                 $('<p>').text(gt.pgettext('tour', 'What you can do now:')),
-                $('<p>').append($('<a href="#">').click(writeMail).text(gt.pgettext('tour', 'Write an encrypted email'))),
-                $('<p>').append($('<a href="#">').click(openFiles).text(gt.pgettext('tour', 'Encrypt your sensitive files in Drive'))),
+                $('<p>').append($('<a href="#">').click(function () {
+                    writeMail();
+                    tour.close();
+                }).text(gt.pgettext('tour', 'Write an encrypted email'))),
+                driveText,
                 $('<hr>'),
                 $('<p>').append($('<a href="#">').click(setEncryptDefault).text(gt.pgettext('tour', 'Activate encryption for all new emails'))),
                 $('<p>').append($('<a href="#">').click(openSettings).text(gt.pgettext('tour', 'Review your encryption settings'))),
@@ -198,7 +250,7 @@ define('oxguard/tour/main', [
     }, function () {
         var def = $.Deferred();
 
-        if (util.isGuardConfigured()) return def.reject('configured');
+        var configured = util.isGuardConfigured();
 
         if (_.device('small') || _.device('smartphone')) {
             return core.createKeys();
@@ -223,15 +275,21 @@ define('oxguard/tour/main', [
             model.off();
             view = model = null;
         });
-        //Guard is not configured, yet. Abort after this step in order to allow the user to start the configuration.
-        tour.step()
-            .title(gt.pgettext('tour', 'Create Your Guard Account'))
+        //Guard is not configured, yet.
+        if (!configured) {
+            tour.step({ labelNext: gt('Start Setup') })
+            .title(gt.format(gt.pgettext('tour', 'Setup %s'), window.oxguarddata.productName))
             .content($('<div>').append(
-                $('<p>').text(gt.pgettext('tour', 'You now need to choose a password which will be used to encrypt or decrypt items. You only need to set this up once. Your password will then remain valid until you change it.'))
-            ))
+                  //#. %s product name
+                $('<p>').text(gt.format(gt.pgettext('tour', 'Welcome to %1$s. You will now be taken on a tour, showing you how to use %1$s.'),
+                        window.oxguarddata.productName)))
+                .append($('<p>').text(gt.format(gt.pgettext('tour', 'Firstly however, you’ll need to setup %1$s by choosing a password which will be used to encrypt or decrypt items such as email or files.'
+                        ), window.oxguarddata.productName)))
+                )
             .end()
         .step()
-            .title(gt('Create Guard Security Keys'))
+            //#. %s product name
+            .title(gt('Choose %s Password', window.oxguarddata.productName))
             .content(view.render().$el)
             .beforeShow(function () {
                 var self = this;
@@ -247,19 +305,29 @@ define('oxguard/tour/main', [
             .on('next', function () {
                 model.send();
             })
-            .end()
-        .step()
-            .title(gt.pgettext('tour', 'Guard set up completed'))
+            .end();
+        }
+
+        // If we are already configured, can start with the offer for more tour
+        if (configured) {
+            $('body').addClass('og-ready');
+        }
+
+        tour
+        .step({ labelDone: gt('Close') })
+            //#. %s product Name
+            .title(gt.format(gt.pgettext('tour', '%s set up completed'), window.oxguarddata.productName))
             .content($('<div>').append(
-                $('<p>').text(gt.pgettext('tour', 'You successfully set up secure communication. Your private key has been created.')),
-                $('<p>').text(gt.pgettext('tour', 'What you can do now:')),
+                $('<p>').text(gt.format(gt.pgettext('tour', 'Congratulations, you have successfully setup %s'), window.oxguarddata.productName)),
+                $('<p>').text(gt.format(gt.pgettext('tour', 'Now you can learn more about how to use %s by following the links below:'), window.oxguarddata.productName)),
                 $('<p>').append($('<a href="#">').click(function () {
                     $('.wizard-step .btn-primary').click();
                     Tour.registry.run('default/oxguard');
-                }).text(gt('Guided tour for Guard'))),
+                    //#. %s product name
+                }).text(gt('Guided tour for %s', window.oxguarddata.productName))),
                 $('<p>').append(new HelpView({
                     base: 'help-guard',
-                    content: gt.pgettext('tour', 'Learn more')
+                    content: gt.format(gt.pgettext('tour', 'Learn more about %s'), window.oxguarddata.productName)
                 }).render().$el)
             ))
             .mandatory()
@@ -282,8 +350,8 @@ define('oxguard/tour/main', [
         id: 'default/oxguard/choice',
         priority: 1
     }, function () {
-        return require(['settings!oxguard', 'oxguard/tour/choice', 'mailvelope/main', 'io.ox/core/capabilities'])
-        .then(function (settings, Choice, api, capabilities) {
+        return require(['settings!oxguard', 'oxguard/tour/choice', 'mailvelope/main'])
+        .then(function (settings, Choice, api) {
 
             var def = $.Deferred();
 
@@ -311,6 +379,7 @@ define('oxguard/tour/main', [
                     this.$('[data-action="done"]').hide();
 
                     model.on('change:cryptoProvider', function (model, provider) {
+                        settings.set('cryptoProvider', model.get('cryptoProvider'));
                         settings.save();
                         def.resolve(provider);
                         tour.trigger('done');
